@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ *
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -768,18 +773,25 @@ UnitDefinition::simplify(UnitDefinition * ud)
     kindsList.append(UnitKind_toString(ud->getUnit(n)->getKind()));
   }
   
+  double dimMultfactor = 1.0;
+  
   /* if only one unit cannot be simplified any further */
   if (units->size() > 1)
   {
     if (kindsList.contains("dimensionless"))
     {
       /* if contains a dimensionless unit and any others then 
-        dimensionless is unecessary */
+        dimensionless is unecessary 
+        unless it has a multiplier attached
+        */
       for (n = 0; n < units->size(); n++)
       {
         unit = (Unit *) units->get(n);
         if (!strcmp(UnitKind_toString(unit->getKind()), "dimensionless"))
         {
+          dimMultfactor = pow(unit->getMultiplier(), unit->getExponent());
+          if (util_isEqual(dimMultfactor, 1.0) == false)
+            cancelFlag = 1;
           delete units->remove(n);
           kindsList.removeUnitKind("dimensionless");
         }
@@ -812,6 +824,8 @@ UnitDefinition::simplify(UnitDefinition * ud)
   }
 
   /* may have cancelled units - in which case exponent will be 0 */
+  // might need to propagate a multiplier though
+  double newMultiplier = dimMultfactor;
   unsigned int numUnits = units->size();
   for (n = numUnits; n > 0; n--)
   {
@@ -820,25 +834,40 @@ UnitDefinition::simplify(UnitDefinition * ud)
     {
       if (unit->getExponentUnitChecking() == 0)
       {
+        newMultiplier = newMultiplier * unit->getMultiplier();
         delete units->remove(n-1);
         cancelFlag = 1;
       }
     }
     else if (unit->getExponent() == 0)
     {
+      newMultiplier = newMultiplier * unit->getMultiplier();
       delete units->remove(n-1);
       cancelFlag = 1;
     }
   }
 
   /* if all units have been cancelled need to add dimensionless */
-  if (units->size() == 0 && cancelFlag == 1)
+  /* or indeed if one or more have been cancelled need to
+   * propagate any remaining multiplier */
+  if (cancelFlag == 1)
   {
-    Unit tmpunit(ud->getSBMLNamespaces());
-    tmpunit.setKind(UNIT_KIND_DIMENSIONLESS);
-    tmpunit.initDefaults();
-    ud->addUnit(&tmpunit);
+    if (units->size() == 0)
+    {
+      Unit tmpunit(ud->getSBMLNamespaces());
+      tmpunit.setKind(UNIT_KIND_DIMENSIONLESS);
+      tmpunit.initDefaults();
+      tmpunit.setMultiplier(newMultiplier);
+      ud->addUnit(&tmpunit);
+    }
+    else if (util_isEqual(newMultiplier, 1.0) == false)
+    {
+      unit = units->get(0);
+      unit->setMultiplier(unit->getMultiplier() * 
+        pow(newMultiplier, 1.0/unit->getExponentAsDouble()));
+    }
   }
+
 }
 
 /** @cond doxygenLibsbmlInternal */
@@ -951,6 +980,41 @@ UnitDefinition::convertToSI(const UnitDefinition * ud)
 }
 
 
+double
+extractMultiplier(UnitDefinition * ud)
+{
+  double multiplier = 1.0;
+
+  unsigned int i = 0;
+  while(i < ud->getNumUnits())
+  {
+    Unit::removeScale(ud->getUnit(i));
+    multiplier = multiplier * pow(ud->getUnit(i)->getMultiplier(), 
+                                  ud->getUnit(i)->getExponentAsDouble());
+    ud->getUnit(i)->setMultiplier(1.0);
+    ud->getUnit(i)->setScale(0);
+    i++;
+  }
+  return multiplier;
+}
+
+
+///* slightly less restrictive version that util_isEqual
+// * I had issues with this when one of the multipliers
+// * had not been calculated and was just 1.0
+// */
+//bool
+//isEqual(double a, double b)
+//{
+//  double tol;
+//  if (a < b)
+//    tol = a * 1e-10;
+//  else
+//    tol = b * 1e-10;
+//  return (fabs(a-b) < sqrt(tol)) ? true : false;
+//}
+
+
 /* 
  * Predicate returning @c true if 
  * UnitDefinition objects are identical (all units are identical).
@@ -1010,14 +1074,31 @@ UnitDefinition::areIdentical(const UnitDefinition * ud1,
   for ( n = 0; n < ud2->getNumUnits(); n++)
     ud2Temp->addUnit(ud2->getUnit(n));
 
+  UnitDefinition::simplify(ud1Temp);
+  UnitDefinition::simplify(ud2Temp);
 
-  if (ud1->getNumUnits() == ud2->getNumUnits())
+  if (ud1Temp->getNumUnits() == ud2Temp->getNumUnits())
   {
     UnitDefinition::reorder(ud1Temp);
     UnitDefinition::reorder(ud2Temp);
+
+    if (ud1Temp->getNumUnits() > 1)
+    {
+      // different multipliers left on different units may not match
+      // but overall they 
+      // e.g (2m)(sec) is tha same unit as (m)(2sec) but unit by unit
+      // comparison will fail
+      double multiplier1 = extractMultiplier(ud1Temp);
+      double multiplier2 = extractMultiplier(ud2Temp);
+
+      if (util_isEqual(multiplier1, multiplier2) == false)
+      {
+        return identical;
+      }
+    }
     
     n = 0;
-    while (n < ud1->getNumUnits())
+    while (n < ud1Temp->getNumUnits())
     {
       if (!Unit::areIdentical(ud1Temp->getUnit(n), ud2Temp->getUnit(n)))
       {
@@ -1028,7 +1109,7 @@ UnitDefinition::areIdentical(const UnitDefinition * ud1,
         n++;
       }
     }
-    if (n == ud1->getNumUnits())
+    if (n == ud1Temp->getNumUnits())
     {
       identical = true;
     }
@@ -1151,16 +1232,51 @@ UnitDefinition::areIdenticalSIUnits(const UnitDefinition * ud1,
     UnitDefinition::reorder(ud1Temp);
     UnitDefinition::reorder(ud2Temp);
     
+    if (ud1Temp->getNumUnits() > 1)
+    {
+      // different multipliers left on different units may not match
+      // but overall they 
+      // e.g (2m)(sec) is tha same unit as (m)(2sec) but unit by unit
+      // comparison will fail
+      double multiplier1 = extractMultiplier(ud1Temp);
+      double multiplier2 = extractMultiplier(ud2Temp);
+
+      if (util_isEqual(multiplier1, multiplier2) == false)
+      {
+        return identical;
+      }
+    }
+
     n = 0;
     while (n < ud1Temp->getNumUnits())
     {
-      if (!Unit::areIdentical(ud1Temp->getUnit(n), ud2Temp->getUnit(n)))
+      Unit* u1 = ud1Temp->getUnit(n);
+      Unit* u2 = ud2Temp->getUnit(n);
+      // if the unit is dimensionless it does not matter 
+      // what numerical factors it has
+      // but put this check here rather than in the unit areIdentical
+      // so that Unit::areIdentical is trully a test for identical
+      if (u1->getKind() == UNIT_KIND_DIMENSIONLESS)
       {
-        break;
+        if (u2->getKind() != UNIT_KIND_DIMENSIONLESS)
+        {
+          break;
+        }
+        else
+        {
+          n++;
+        }
       }
       else
       {
-        n++;
+        if (!Unit::areIdentical(u1, u2))
+        {
+          break;
+        }
+        else
+        {
+          n++;
+        }
       }
     }
     if (n == ud1Temp->getNumUnits())
@@ -1791,7 +1907,7 @@ ListOfUnitDefinitions::createObject (XMLInputStream& stream)
 
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
+/** @cond doxygenIgnored */
 
 
 LIBSBML_EXTERN
