@@ -5,7 +5,7 @@
  * 
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -527,54 +527,54 @@ Date::parseDateStringToNumbers()
     year[2] = cdate[2];
     year[3] = cdate[3];
 
-    mYear = strtol(year, NULL, 10);
+    mYear = (int)strtol(year, NULL, 10);
 
     block[0] = cdate[5];
     block[1] = cdate[6];
     
-    mMonth = strtol(block, NULL, 10);
+    mMonth = (int)strtol(block, NULL, 10);
 
     block[0] = cdate[8];
     block[1] = cdate[9];
     
-    mDay = strtol(block, NULL, 10);
+    mDay = (int)strtol(block, NULL, 10);
 
     block[0] = cdate[11];
     block[1] = cdate[12];
     
-    mHour = strtol(block, NULL, 10);
+    mHour = (int)strtol(block, NULL, 10);
 
     block[0] = cdate[14];
     block[1] = cdate[15];
     
-    mMinute = strtol(block, NULL, 10);
+    mMinute = (int)strtol(block, NULL, 10);
 
     block[0] = cdate[17];
     block[1] = cdate[18];
     
-    mSecond = strtol(block, NULL, 10);
+    mSecond = (int)strtol(block, NULL, 10);
 
     if (cdate[19] == '+')
     {
       mSignOffset = 1;
       block[0] = cdate[20];
       block[1] = cdate[21];
-      mHoursOffset = strtol(block, NULL, 10);
+      mHoursOffset = (int)strtol(block, NULL, 10);
 
       block[0] = cdate[23];
       block[1] = cdate[24];
-      mMinutesOffset = strtol(block, NULL, 10);
+      mMinutesOffset = (int)strtol(block, NULL, 10);
     }
     else if (cdate[19] == '-')
     {
       mSignOffset = 0;
       block[0] = cdate[20];
       block[1] = cdate[21];
-      mHoursOffset = strtol(block, NULL, 10);
+      mHoursOffset = (int)strtol(block, NULL, 10);
 
       block[0] = cdate[23];
       block[1] = cdate[24];
-      mMinutesOffset = strtol(block, NULL, 10);
+      mMinutesOffset = (int)strtol(block, NULL, 10);
     }
     else
     {
@@ -675,24 +675,8 @@ Date::resetModifiedFlags()
 #endif /* __cplusplus */
 
 
-/** @cond doxygenCOnly */
+/** @cond doxygenIgnored */
 
-/**
- * Creates a date optionally from the individual fields entered as numbers.
- *
- * @param year an unsigned int representing the year.
- * @param month an unsigned int representing the month.
- * @param day an unsigned int representing the day.
- * @param hour an unsigned int representing the hour.
- * @param minute an unsigned int representing the minute.
- * @param second an unsigned int representing the second.
- * @param sign an unsigned int representing the sign of the offset 
- * (0/1 equivalent to +/-). 
- * @param hoursOffset an unsigned int representing the hoursOffset.
- * @param minutesOffset an unsigned int representing the minutesOffset.
- *
- * @return pointer to the newly created Date_t structure.
- */
 LIBSBML_EXTERN
 Date_t *
 Date_createFromValues(unsigned int year, unsigned int month, 
@@ -706,17 +690,6 @@ Date_createFromValues(unsigned int year, unsigned int month,
 }
 
 
-/**
- * Creates a date from a string.
- *
- * @param date a string representing the date.
- *
- * @return pointer to the newly created Date_t structure.
- *
- * @note the string should be in W3CDTF format 
- * YYYY-MM-DDThh:mm:ssTZD (eg 1997-07-16T19:20:30+01:00)
- * where TZD is the time zone designator.
- */
 LIBSBML_EXTERN
 Date_t *
 Date_createFromString (const char * date)
@@ -726,11 +699,6 @@ Date_createFromString (const char * date)
 }
 
 
-/**
- * Destroys this Date.
- *
- * @param date Date_t structure to be freed.
- */
 LIBSBML_EXTERN
 void
 Date_free(Date_t * date)
@@ -739,13 +707,6 @@ Date_free(Date_t * date)
 }
 
 
-/**
- * Creates a deep copy of the given Date_t structure
- * 
- * @param date the Date_t structure to be copied
- * 
- * @return a (deep) copy of the given Date_t structure.
- */
 LIBSBML_EXTERN
 Date_t *
 Date_clone (const Date_t* date)
@@ -755,13 +716,6 @@ Date_clone (const Date_t* date)
 }
 
 
-/**
- * Returns the Date as a string.
- *
- * @param date the Date_t structure to be queried
- * 
- * @return the date as a string.
- */
 LIBSBML_EXTERN
 const char *
 Date_getDateAsString(Date_t * date)
@@ -771,13 +725,6 @@ Date_getDateAsString(Date_t * date)
 }
 
 
-/**
- * Returns the year from this Date.
- *
- * @param date the Date_t structure to be queried
- * 
- * @return the year from this Date.
- */
 LIBSBML_EXTERN
 unsigned int
 Date_getYear(Date_t * date)
@@ -787,13 +734,6 @@ Date_getYear(Date_t * date)
 }
 
 
-/**
- * Returns the month from this Date.
- *
- * @param date the Date_t structure to be queried
- * 
- * @return the month from this Date.
- */
 LIBSBML_EXTERN
 unsigned int
 Date_getMonth(Date_t * date)
@@ -803,13 +743,6 @@ Date_getMonth(Date_t * date)
 }
 
 
-/**
- * Returns the day from this Date.
- *
- * @param date the Date_t structure to be queried
- * 
- * @return the day from this Date.
- */
 LIBSBML_EXTERN
 unsigned int
 Date_getDay(Date_t * date)
@@ -819,13 +752,6 @@ Date_getDay(Date_t * date)
 }
 
 
-/**
- * Returns the hour from this Date.
- *
- * @param date the Date_t structure to be queried
- * 
- * @return the hour from this Date.
- */
 LIBSBML_EXTERN
 unsigned int
 Date_getHour(Date_t * date)
@@ -835,13 +761,6 @@ Date_getHour(Date_t * date)
 }
 
 
-/**
- * Returns the minute from this Date.
- *
- * @param date the Date_t structure to be queried
- * 
- * @return the minute from this Date.
- */
 LIBSBML_EXTERN
 unsigned int
 Date_getMinute(Date_t * date)
@@ -851,13 +770,6 @@ Date_getMinute(Date_t * date)
 }
 
 
-/**
- * Returns the seconds from this Date.
- *
- * @param date the Date_t structure to be queried
- * 
- * @return the seconds from this Date.
- */
 LIBSBML_EXTERN
 unsigned int
 Date_getSecond(Date_t * date) 
@@ -867,13 +779,6 @@ Date_getSecond(Date_t * date)
 } 
 
 
-/**
- * Returns the sign of the offset from this Date.
- *
- * @param date the Date_t structure to be queried
- * 
- * @return the sign of the offset from this Date.
- */
 LIBSBML_EXTERN
 unsigned int
 Date_getSignOffset(Date_t * date) 
@@ -883,13 +788,6 @@ Date_getSignOffset(Date_t * date)
 } 
 
 
-/**
- * Returns the hours of the offset from this Date.
- *
- * @param date the Date_t structure to be queried
- * 
- * @return the hours of the offset from this Date.
- */
 LIBSBML_EXTERN
 unsigned int
 Date_getHoursOffset(Date_t * date) 
@@ -899,13 +797,6 @@ Date_getHoursOffset(Date_t * date)
 } 
 
 
-/**
- * Returns the minutes of the offset from this Date.
- *
- * @param date the Date_t structure to be queried
- * 
- * @return the minutes of the offset from this Date.
- */
 LIBSBML_EXTERN
 unsigned int
 Date_getMinutesOffset(Date_t * date) 
@@ -915,20 +806,6 @@ Date_getMinutesOffset(Date_t * date)
 } 
 
 
-/**
- * Sets the value of the year checking appropriateness.
- *  
- * @param date the Date_t structure to be set
- * @param value an unsigned int representing the year to set.  
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
- * @li LIBSBML_INVALID_OBJECT
- */
 LIBSBML_EXTERN
 int
 Date_setYear(Date_t * date, unsigned int value) 
@@ -938,20 +815,6 @@ Date_setYear(Date_t * date, unsigned int value)
 }
 
 
-/**
- * Sets the value of the month checking appropriateness.
- *  
- * @param date the Date_t structure to be set
- * @param value an unsigned int representing the month to set.  
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
- * @li LIBSBML_INVALID_OBJECT
- */
 LIBSBML_EXTERN
 int
 Date_setMonth(Date_t * date, unsigned int value) 
@@ -961,20 +824,6 @@ Date_setMonth(Date_t * date, unsigned int value)
 }
 
 
-/**
- * Sets the value of the day checking appropriateness.
- *  
- * @param date the Date_t structure to be set
- * @param value an unsigned int representing the day to set.  
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
- * @li LIBSBML_INVALID_OBJECT
- */
 LIBSBML_EXTERN
 int
 Date_setDay(Date_t * date, unsigned int value) 
@@ -984,20 +833,6 @@ Date_setDay(Date_t * date, unsigned int value)
 }
 
 
-/**
- * Sets the value of the hour checking appropriateness.
- *  
- * @param date the Date_t structure to be set
- * @param value an unsigned int representing the hour to set.  
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
- * @li LIBSBML_INVALID_OBJECT;
- */
 LIBSBML_EXTERN
 int
 Date_setHour(Date_t * date, unsigned int value) 
@@ -1007,20 +842,6 @@ Date_setHour(Date_t * date, unsigned int value)
 }
 
 
-/**
- * Sets the value of the minute checking appropriateness.
- *  
- * @param date the Date_t structure to be set
- * @param value an unsigned int representing the minute to set.  
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
- * @li LIBSBML_INVALID_OBJECT
- */
 LIBSBML_EXTERN
 int
 Date_setMinute(Date_t * date, unsigned int value) 
@@ -1030,20 +851,6 @@ Date_setMinute(Date_t * date, unsigned int value)
 }
 
 
-/**
- * Sets the value of the second checking appropriateness.
- *  
- * @param date the Date_t structure to be set
- * @param value an unsigned int representing the second to set.  
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
- * @li LIBSBML_INVALID_OBJECT
- */
 LIBSBML_EXTERN
 int
 Date_setSecond(Date_t * date, unsigned int value) 
@@ -1053,21 +860,6 @@ Date_setSecond(Date_t * date, unsigned int value)
 }
 
 
-/**
- * Sets the value of the offset sign checking appropriateness.
- *  
- * @param date the Date_t structure to be set
- * @param value an unsigned int representing the sign of the 
- * offset to set.  
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
- * @li LIBSBML_INVALID_OBJECT
- */
 LIBSBML_EXTERN
 int
 Date_setSignOffset(Date_t * date, unsigned int value) 
@@ -1077,21 +869,6 @@ Date_setSignOffset(Date_t * date, unsigned int value)
 }
 
 
-/**
- * Sets the value of the offset hour checking appropriateness.
- *  
- * @param date the Date_t structure to be set
- * @param value an unsigned int representing the hours of the 
- * offset to set.  
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
- * @li LIBSBML_INVALID_OBJECT
- */
 LIBSBML_EXTERN
 int
 Date_setHoursOffset(Date_t * date, unsigned int value) 
@@ -1101,21 +878,6 @@ Date_setHoursOffset(Date_t * date, unsigned int value)
 }
 
 
-/**
- * Sets the value of the offset minutes checking appropriateness.
- *  
- * @param date the Date_t structure to be set
- * @param value an unsigned int representing the minutes of the 
- * offset to set.  
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
- * @li LIBSBML_INVALID_OBJECT
- */
 LIBSBML_EXTERN
 int
 Date_setMinutesOffset(Date_t * date, unsigned int value) 
@@ -1124,20 +886,6 @@ Date_setMinutesOffset(Date_t * date, unsigned int value)
   return date->setMinutesOffset(value); 
 }
 
-/**
- * Sets the value of the date from a string.
- *  
- * @param date the Date_t structure to be set
- * @param str string representing the date to set.  
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
- * @li LIBSBML_INVALID_OBJECT
- */
 LIBSBML_EXTERN
 int
 Date_setDateAsString(Date_t * date, const char *str)
