@@ -7,8 +7,15 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright 2011 California Institute of Technology.
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
  * 
+ * Copyright 2011-2012 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *
  * This library is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.  A copy of the license agreement is provided
@@ -520,6 +527,7 @@ SBaseRef::createSBaseRef ()
   {
     COMP_CREATE_NS(compns, getSBMLNamespaces());
     mSBaseRef = new SBaseRef(compns);
+    delete compns;
   }
   catch (...)
   {
@@ -631,6 +639,7 @@ SBaseRef::createObject (XMLInputStream& stream)
       mSBaseRef = new SBaseRef(compns);
       object = mSBaseRef;
       object->connectToParent(this);
+      delete compns;
     }
     else if ( name == "sbaseRef" ) {
       if (errlog != NULL) {
@@ -641,6 +650,7 @@ SBaseRef::createObject (XMLInputStream& stream)
       mSBaseRef = new SBaseRef(compns);
       object = mSBaseRef;
       object->connectToParent(this);
+      delete compns;
     }
   }
   return object;
@@ -948,7 +958,7 @@ int SBaseRef::collectDeletions(set<SBase*>* removed, set<SBase*>* toremove)
   CompSBasePlugin* todplug = static_cast<CompSBasePlugin*>(todelete->getPlugin(getPrefix()));
   if (todplug != NULL) {
     for (unsigned long re=0; re<todplug->getNumReplacedElements(); re++) {
-      todplug->getReplacedElement(re)->collectDeletions(removed, toremove);
+      todplug->getReplacedElement((unsigned int)re)->collectDeletions(removed, toremove);
     }
     if (todplug->isSetReplacedBy()) {
       todplug->getReplacedBy()->collectDeletions(removed, toremove);
@@ -961,7 +971,7 @@ int SBaseRef::collectDeletions(set<SBase*>* removed, set<SBase*>* toremove)
 int SBaseRef::performDeletion()
 {
   set<SBase*> toremove;
-  set<SBase*>* removed;
+  set<SBase*>* removed=NULL;
   CompModelPlugin* cmp = NULL;
   SBase* parent = getParentSBMLObject();
   while (parent != NULL && parent->getTypeCode() != SBML_DOCUMENT) {
@@ -974,7 +984,7 @@ int SBaseRef::performDeletion()
     }
     parent = parent->getParentSBMLObject();
   }
-  int ret = collectDeletions(removed, &toremove);
+  int ret = removed != NULL ? collectDeletions(removed, &toremove) : LIBSBML_INVALID_OBJECT ;
   if (ret != LIBSBML_OPERATION_SUCCESS) {
     return ret;
   }
@@ -1016,11 +1026,8 @@ SBase* SBaseRef::getDirectReference()
 /** @endcond */
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
+/** @cond doxygenIgnored */
 
-/**
- * 
- */
 LIBSBML_EXTERN
 SBaseRef_t *
 SBaseRef_create(unsigned int level, unsigned int version,
@@ -1030,9 +1037,6 @@ SBaseRef_create(unsigned int level, unsigned int version,
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 void
 SBaseRef_free(SBaseRef_t * sbr)
@@ -1042,9 +1046,6 @@ SBaseRef_free(SBaseRef_t * sbr)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 SBaseRef_t *
 SBaseRef_clone(SBaseRef_t * sbr)
@@ -1060,9 +1061,6 @@ SBaseRef_clone(SBaseRef_t * sbr)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 char *
 SBaseRef_getPortRef(SBaseRef_t * sbr)
@@ -1074,9 +1072,6 @@ SBaseRef_getPortRef(SBaseRef_t * sbr)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 char *
 SBaseRef_getIdRef(SBaseRef_t * sbr)
@@ -1088,9 +1083,6 @@ SBaseRef_getIdRef(SBaseRef_t * sbr)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 char *
 SBaseRef_getUnitRef(SBaseRef_t * sbr)
@@ -1102,9 +1094,6 @@ SBaseRef_getUnitRef(SBaseRef_t * sbr)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 char *
 SBaseRef_getMetaIdRef(SBaseRef_t * sbr)
@@ -1116,9 +1105,6 @@ SBaseRef_getMetaIdRef(SBaseRef_t * sbr)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 SBaseRef_t*
 SBaseRef_getSBaseRef(SBaseRef_t * sbr)
@@ -1130,9 +1116,6 @@ SBaseRef_getSBaseRef(SBaseRef_t * sbr)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 SBaseRef_isSetPortRef(SBaseRef_t * sbr)
@@ -1141,9 +1124,6 @@ SBaseRef_isSetPortRef(SBaseRef_t * sbr)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 SBaseRef_isSetIdRef(SBaseRef_t * sbr)
@@ -1152,9 +1132,6 @@ SBaseRef_isSetIdRef(SBaseRef_t * sbr)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 SBaseRef_isSetUnitRef(SBaseRef_t * sbr)
@@ -1163,9 +1140,6 @@ SBaseRef_isSetUnitRef(SBaseRef_t * sbr)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 SBaseRef_isSetMetaIdRef(SBaseRef_t * sbr)
@@ -1174,9 +1148,6 @@ SBaseRef_isSetMetaIdRef(SBaseRef_t * sbr)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 SBaseRef_isSetSBaseRef(SBaseRef_t * sbr)
@@ -1185,9 +1156,6 @@ SBaseRef_isSetSBaseRef(SBaseRef_t * sbr)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 SBaseRef_setPortRef(SBaseRef_t * sbr, const char * portRef)
@@ -1196,9 +1164,6 @@ SBaseRef_setPortRef(SBaseRef_t * sbr, const char * portRef)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 SBaseRef_setIdRef(SBaseRef_t * sbr, const char * idRef)
@@ -1207,9 +1172,6 @@ SBaseRef_setIdRef(SBaseRef_t * sbr, const char * idRef)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 SBaseRef_setUnitRef(SBaseRef_t * sbr, const char * unitRef)
@@ -1218,9 +1180,6 @@ SBaseRef_setUnitRef(SBaseRef_t * sbr, const char * unitRef)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 SBaseRef_setMetaIdRef(SBaseRef_t * sbr, const char * metaIdRef)
@@ -1229,9 +1188,6 @@ SBaseRef_setMetaIdRef(SBaseRef_t * sbr, const char * metaIdRef)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 SBaseRef_setSBaseRef(SBaseRef_t * sbr, SBaseRef_t * sBaseRef)
@@ -1240,9 +1196,6 @@ SBaseRef_setSBaseRef(SBaseRef_t * sbr, SBaseRef_t * sBaseRef)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 SBaseRef_unsetPortRef(SBaseRef_t * sbr)
@@ -1251,9 +1204,6 @@ SBaseRef_unsetPortRef(SBaseRef_t * sbr)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 SBaseRef_unsetIdRef(SBaseRef_t * sbr)
@@ -1262,9 +1212,6 @@ SBaseRef_unsetIdRef(SBaseRef_t * sbr)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 SBaseRef_unsetUnitRef(SBaseRef_t * sbr)
@@ -1273,9 +1220,6 @@ SBaseRef_unsetUnitRef(SBaseRef_t * sbr)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 SBaseRef_unsetMetaIdRef(SBaseRef_t * sbr)
@@ -1284,9 +1228,6 @@ SBaseRef_unsetMetaIdRef(SBaseRef_t * sbr)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 SBaseRef_unsetSBaseRef(SBaseRef_t * sbr)
@@ -1295,9 +1236,6 @@ SBaseRef_unsetSBaseRef(SBaseRef_t * sbr)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 SBaseRef_hasRequiredAttributes(SBaseRef_t * sbr)
