@@ -7,8 +7,15 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright 2011 California Institute of Technology.
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
  * 
+ * Copyright 2011-2012 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *
  * This library is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.  A copy of the license agreement is provided
@@ -47,7 +54,6 @@ Submodel::Submodel (unsigned int level, unsigned int version, unsigned int pkgVe
   , mId("")
   , mName("")
   , mModelRef("")
-  , mSubstanceConversionFactor("")
   , mTimeConversionFactor("")
   , mExtentConversionFactor("")
   , mListOfDeletions()
@@ -63,7 +69,6 @@ Submodel::Submodel(CompPkgNamespaces* compns)
   , mId("")
   , mName("")
   , mModelRef("")
-  , mSubstanceConversionFactor("")
   , mTimeConversionFactor("")
   , mExtentConversionFactor("")
   , mListOfDeletions()
@@ -80,7 +85,6 @@ Submodel::Submodel(const Submodel& source)
   , mId(source.mId)
   , mName(source.mName)
   , mModelRef(source.mModelRef)
-  , mSubstanceConversionFactor(source.mSubstanceConversionFactor)
   , mTimeConversionFactor(source.mTimeConversionFactor)
   , mExtentConversionFactor(source.mExtentConversionFactor)
   , mListOfDeletions(source.mListOfDeletions)
@@ -98,7 +102,6 @@ Submodel& Submodel::operator=(const Submodel& source)
     mId = source.mId;
     mName = source.mName;
     mModelRef = source.mModelRef;
-    mSubstanceConversionFactor = source.mSubstanceConversionFactor;
     mTimeConversionFactor = source.mTimeConversionFactor;
     mExtentConversionFactor = source.mExtentConversionFactor;
     mListOfDeletions = source.mListOfDeletions;
@@ -279,42 +282,29 @@ Submodel::unsetModelRef ()
 int
 Submodel::setSubstanceConversionFactor (const std::string& substanceConversionFactor)
 {
-  if (!SyntaxChecker::isValidSBMLSId(substanceConversionFactor)) 
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  mSubstanceConversionFactor = substanceConversionFactor;
-  return LIBSBML_OPERATION_SUCCESS;
+  return LIBSBML_INVALID_ATTRIBUTE_VALUE;
 }
 
 
 const string&
 Submodel::getSubstanceConversionFactor () const
 {
-  return mSubstanceConversionFactor;
+  static string blank("");
+  return blank;
 }
 
 
 bool
 Submodel::isSetSubstanceConversionFactor () const
 {
-  return (mSubstanceConversionFactor.empty() == false);
+  return false;
 }
 
 
 int
 Submodel::unsetSubstanceConversionFactor ()
 {
-  mSubstanceConversionFactor.erase();
-
-  if (mSubstanceConversionFactor.empty())
-  {
-    return LIBSBML_OPERATION_SUCCESS;
-  }
-  else
-  {
-    return LIBSBML_OPERATION_FAILED;
-  }
+  return LIBSBML_OPERATION_FAILED;
 }
 
 
@@ -498,6 +488,7 @@ Submodel::createDeletion ()
   COMP_CREATE_NS(compns, getSBMLNamespaces());
   Deletion* m = new Deletion(compns);
   mListOfDeletions.appendAndOwn(m);
+  delete compns;
   return m;
 }
 
@@ -530,7 +521,6 @@ Submodel::addExpectedAttributes(ExpectedAttributes& attributes)
   attributes.add("id");
   attributes.add("name");
   attributes.add("modelRef");
-  attributes.add("substanceConversionFactor");
   attributes.add("timeConversionFactor");
   attributes.add("extentConversionFactor");
 }
@@ -639,12 +629,6 @@ Submodel::readAttributes (const XMLAttributes& attributes,
         logInvalidId("comp:modelRef", mModelRef, "Submodel");
       }
     }
-    XMLTriple triplescf("substanceConversionFactor", mURI, getPrefix());
-    if (attributes.readInto(triplescf, mSubstanceConversionFactor, getErrorLog(), false, getLine(), getColumn())) {
-      if (!SyntaxChecker::isValidSBMLSId(mSubstanceConversionFactor)) {
-        logInvalidId("comp:substanceConversionFactor", mSubstanceConversionFactor);
-      }
-    }
     XMLTriple tripletcf("timeConversionFactor", mURI, getPrefix());
     if (attributes.readInto(tripletcf, mTimeConversionFactor, getErrorLog(), false, getLine(), getColumn())) {
       if (!SyntaxChecker::isValidSBMLSId(mTimeConversionFactor)) {
@@ -676,9 +660,6 @@ Submodel::writeAttributes (XMLOutputStream& stream) const
   if (isSetModelRef()) {
     stream.writeAttribute("modelRef", getPrefix(), mModelRef);
   }
-  if (isSetSubstanceConversionFactor()) {
-    stream.writeAttribute("substanceConversionFactor", getPrefix(), mSubstanceConversionFactor);
-  }
   if (isSetTimeConversionFactor()) {
     stream.writeAttribute("timeConversionFactor", getPrefix(), mTimeConversionFactor);
   }
@@ -1016,6 +997,7 @@ Submodel::replaceElement(SBase* toReplace, SBase* replacement)
     }
   }
 
+  delete allelements;
   return LIBSBML_OPERATION_FAILED;
 }
 
@@ -1059,7 +1041,8 @@ Submodel::getAllInstantiatedElements()
   }
   for (size_t l=0; l<sublists.size(); l++) {
     allElements->transferFrom(sublists[l]);
-  }
+    delete sublists[l];
+  }  
   return allElements;
 }
 
@@ -1226,7 +1209,7 @@ int Submodel::convertTimeAndExtentWith(const ASTNode* tcf, const ASTNode* xcf, c
         //Rate rules are divided by the time conversion factor.
         rrule = static_cast<RateRule*>(element);
         if (rrule->isSetMath()) {
-          ast1 = rrule->getMath()->deepCopy();
+          //ast1 = rrule->getMath()->deepCopy();
           tcfdiv->insertChild(0, rrule->getMath()->deepCopy());
           rrule->setMath(tcfdiv);
           tcfdiv->removeChild(0);
@@ -1299,6 +1282,9 @@ int Submodel::convertTimeAndExtentWith(const ASTNode* tcf, const ASTNode* xcf, c
       }
     }
   }
+
+  delete allelements;
+
   return LIBSBML_OPERATION_SUCCESS;
 }
 
@@ -1353,11 +1339,8 @@ void Submodel::createNewConversionFactor(string& cf, const ASTNode* newcf, strin
 
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
+/** @cond doxygenIgnored */
 
-/**
- * 
- */
 LIBSBML_EXTERN
 Submodel_t *
 Submodel_create(unsigned int level, unsigned int version,
@@ -1367,9 +1350,6 @@ Submodel_create(unsigned int level, unsigned int version,
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 void
 Submodel_free(Submodel_t * s)
@@ -1379,9 +1359,6 @@ Submodel_free(Submodel_t * s)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 Submodel_t *
 Submodel_clone(Submodel_t * s)
@@ -1397,9 +1374,6 @@ Submodel_clone(Submodel_t * s)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 char *
 Submodel_getId(Submodel_t * s)
@@ -1411,9 +1385,6 @@ Submodel_getId(Submodel_t * s)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 char *
 Submodel_getName(Submodel_t * s)
@@ -1425,9 +1396,6 @@ Submodel_getName(Submodel_t * s)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 char *
 Submodel_getModelRef(Submodel_t * s)
@@ -1439,23 +1407,14 @@ Submodel_getModelRef(Submodel_t * s)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 char *
 Submodel_getSubstanceConversionFactor(Submodel_t * s)
 {
-  if (s == NULL)
-    return NULL;
-
-  return s->getSubstanceConversionFactor().empty() ? NULL : safe_strdup(s->getSubstanceConversionFactor().c_str());
+  return NULL;
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 char *
 Submodel_getTimeConversionFactor(Submodel_t * s)
@@ -1467,9 +1426,6 @@ Submodel_getTimeConversionFactor(Submodel_t * s)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 char *
 Submodel_getExtentConversionFactor(Submodel_t * s)
@@ -1481,9 +1437,6 @@ Submodel_getExtentConversionFactor(Submodel_t * s)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 Submodel_isSetId(Submodel_t * s)
@@ -1492,9 +1445,6 @@ Submodel_isSetId(Submodel_t * s)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 Submodel_isSetName(Submodel_t * s)
@@ -1503,9 +1453,6 @@ Submodel_isSetName(Submodel_t * s)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 Submodel_isSetModelRef(Submodel_t * s)
@@ -1514,20 +1461,14 @@ Submodel_isSetModelRef(Submodel_t * s)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 Submodel_isSetSubstanceConversionFactor(Submodel_t * s)
 {
-  return (s != NULL) ? static_cast<int>(s->isSetSubstanceConversionFactor()) : 0;
+  return 0;
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 Submodel_isSetTimeConversionFactor(Submodel_t * s)
@@ -1536,9 +1477,6 @@ Submodel_isSetTimeConversionFactor(Submodel_t * s)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 Submodel_isSetExtentConversionFactor(Submodel_t * s)
@@ -1547,9 +1485,6 @@ Submodel_isSetExtentConversionFactor(Submodel_t * s)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 Submodel_setId(Submodel_t * s, const char * id)
@@ -1558,9 +1493,6 @@ Submodel_setId(Submodel_t * s, const char * id)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 Submodel_setName(Submodel_t * s, const char * name)
@@ -1569,9 +1501,6 @@ Submodel_setName(Submodel_t * s, const char * name)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 Submodel_setModelRef(Submodel_t * s, const char * modelRef)
@@ -1580,20 +1509,14 @@ Submodel_setModelRef(Submodel_t * s, const char * modelRef)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
-Submodel_setSubstanceConversionFactor(Submodel_t * s, const char * timeConversionFactor)
+Submodel_setSubstanceConversionFactor(Submodel_t * s, const char * substanceConversionFactor)
 {
-  return (s != NULL) ? s->setSubstanceConversionFactor(timeConversionFactor) : LIBSBML_INVALID_OBJECT;
+  return LIBSBML_INVALID_ATTRIBUTE_VALUE;
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 Submodel_setTimeConversionFactor(Submodel_t * s, const char * timeConversionFactor)
@@ -1602,9 +1525,6 @@ Submodel_setTimeConversionFactor(Submodel_t * s, const char * timeConversionFact
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 Submodel_setExtentConversionFactor(Submodel_t * s, const char * extentConversionFactor)
@@ -1613,9 +1533,6 @@ Submodel_setExtentConversionFactor(Submodel_t * s, const char * extentConversion
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 Submodel_unsetId(Submodel_t * s)
@@ -1624,9 +1541,6 @@ Submodel_unsetId(Submodel_t * s)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 Submodel_unsetName(Submodel_t * s)
@@ -1635,9 +1549,6 @@ Submodel_unsetName(Submodel_t * s)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 Submodel_unsetModelRef(Submodel_t * s)
@@ -1646,20 +1557,14 @@ Submodel_unsetModelRef(Submodel_t * s)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 Submodel_unsetSubstanceConversionFactor(Submodel_t * s)
 {
-  return (s != NULL) ? s->unsetSubstanceConversionFactor() : LIBSBML_INVALID_OBJECT;
+  return LIBSBML_OPERATION_FAILED;
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 Submodel_unsetTimeConversionFactor(Submodel_t * s)
@@ -1668,9 +1573,6 @@ Submodel_unsetTimeConversionFactor(Submodel_t * s)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 Submodel_unsetExtentConversionFactor(Submodel_t * s)
@@ -1679,9 +1581,6 @@ Submodel_unsetExtentConversionFactor(Submodel_t * s)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 Submodel_addDeletion(Submodel_t * s, Deletion_t * d)
@@ -1690,9 +1589,6 @@ Submodel_addDeletion(Submodel_t * s, Deletion_t * d)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 Deletion_t *
 Submodel_createDeletion(Submodel_t * s)
@@ -1701,9 +1597,6 @@ Submodel_createDeletion(Submodel_t * s)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 ListOf_t *
 Submodel_getListOfDeletions(Submodel_t * s)
@@ -1712,9 +1605,6 @@ Submodel_getListOfDeletions(Submodel_t * s)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 Deletion_t *
 Submodel_getDeletion(Submodel_t * s, unsigned int n)
@@ -1723,9 +1613,6 @@ Submodel_getDeletion(Submodel_t * s, unsigned int n)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 Deletion_t *
 Submodel_getDeletionById(Submodel_t * s, const char * sid)
@@ -1734,9 +1621,6 @@ Submodel_getDeletionById(Submodel_t * s, const char * sid)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 unsigned int
 Submodel_getNumDeletions(Submodel_t * s)
@@ -1745,9 +1629,6 @@ Submodel_getNumDeletions(Submodel_t * s)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 Deletion_t *
 Submodel_removeDeletion(Submodel_t * s, unsigned int n)
@@ -1756,9 +1637,6 @@ Submodel_removeDeletion(Submodel_t * s, unsigned int n)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 Deletion_t *
 Submodel_removeDeletionById(Submodel_t * s, const char * sid)
@@ -1767,9 +1645,6 @@ Submodel_removeDeletionById(Submodel_t * s, const char * sid)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 Submodel_hasRequiredAttributes(Submodel_t * s)
@@ -1778,9 +1653,6 @@ Submodel_hasRequiredAttributes(Submodel_t * s)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 Submodel_t *
 ListOfSubmodels_getById(ListOf_t * lo, const char * sid)
@@ -1792,9 +1664,6 @@ ListOfSubmodels_getById(ListOf_t * lo, const char * sid)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 Submodel_t *
 ListOfSubmodels_removeById(ListOf_t * lo, const char * sid)
