@@ -7,8 +7,15 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright 2011 California Institute of Technology.
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
  * 
+ * Copyright 2011-2012 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *
  * This library is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.  A copy of the license agreement is provided
@@ -17,8 +24,7 @@
  * ------------------------------------------------------------------------ -->
  *
  * @class Submodel
- * @sbmlbrief{comp} Implementation of the %Submodel construct from the
- * &ldquo;comp&rdquo; package.
+ * @sbmlbrief{comp} A model instance inside another model.
  *
  * The Submodel class was introduced by the SBML Level&nbsp;3 @ref comp
  * @if java "Hierarchical %Model Composition"@endif@~ package
@@ -115,7 +121,6 @@ protected:
   std::string   mId;
   std::string   mName;
   std::string   mModelRef;
-  std::string   mSubstanceConversionFactor;
   std::string   mTimeConversionFactor;
   std::string   mExtentConversionFactor;
   ListOfDeletions  mListOfDeletions;
@@ -227,8 +232,8 @@ public:
    *
    * @return integer value indicating success/failure of the
    * operation. The possible return values are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE @endlink
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}
    */
   virtual int setId(const std::string& id);
 
@@ -238,8 +243,8 @@ public:
    *
    * @return integer value indicating success/failure of the
    * operation. The possible return values are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_FAILED LIBSBML_OPERATION_FAILED @endlink
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
    */
   virtual int unsetId();
 
@@ -268,8 +273,8 @@ public:
    *
    * @return integer value indicating success/failure of the
    * operation. The possible return values are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE @endlink
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}
    */
   virtual int setName(const std::string& name);
 
@@ -279,8 +284,8 @@ public:
    *
    * @return integer value indicating success/failure of the
    * operation. The possible return values are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_FAILED LIBSBML_OPERATION_FAILED @endlink
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
    */
   virtual int unsetName();
 
@@ -309,8 +314,8 @@ public:
    *
    * @return integer value indicating success/failure of the
    * operation. The possible return values are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE @endlink
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}
    */
   virtual int setModelRef(const std::string& modelRef);
 
@@ -320,50 +325,44 @@ public:
    *
    * @return integer value indicating success/failure of the
    * operation. The possible return values are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_FAILED LIBSBML_OPERATION_FAILED @endlink
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
    */
   virtual int unsetModelRef();
 
 
   /**
-   * Returns the value of the "substanceConversionFactor" attribute of this
-   * Submodel.
+   * Returns an empty string, since "substanceConversionFactor" is not a part of the comp spec.
    *
-   * @return the value of the "substanceConversionFactor" attribute of this Submodel.
+   * @return an empty string
    */
   virtual const std::string& getSubstanceConversionFactor () const;
 
 
   /**
-   * Predicate returning @c true or @c false depending on whether this
-   * Submodel's "substanceConversionFactor" attribute has been set.
+   * Returns @c false, since "substanceConversionFactor" is not a part of the comp spec.
    *
-   * @return @c true if this Submodel's "substanceConversionFactor" attribute has been set, 
-   * otherwise @c false is returned.
+   * @return @c false.
    */
   virtual bool isSetSubstanceConversionFactor () const;
 
   
   /**
-   * Sets the value of the "substanceConversionFactor" attribute of this
-   * Submodel.  Fails if the id is not a valid syntax for an SIdRef.
+   * Automatically fails, since "substanceConversionFactor" is not a part of the comp spec.
    *
    * @return integer value indicating success/failure of the
-   * operation. The possible return values are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE @endlink
+   * operation. The possible return value is:
+   * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}
    */
   virtual int setSubstanceConversionFactor (const std::string& id);
 
 
   /**
-   * Unsets the value of the "substanceConversionFactor" attribute of this Submodel.
+   * Automatically fails, since "substanceConversionFactor" is not a part of the comp spec.
    *
    * @return integer value indicating success/failure of the
-   * operation. The possible return values are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_FAILED LIBSBML_OPERATION_FAILED @endlink
+   * operation. The possible return value is:
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
    */
   virtual int unsetSubstanceConversionFactor ();
 
@@ -392,8 +391,8 @@ public:
    *
    * @return integer value indicating success/failure of the
    * operation. The possible return values are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE @endlink
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}
    */
   virtual int setTimeConversionFactor (const std::string& id);
 
@@ -403,8 +402,8 @@ public:
    *
    * @return integer value indicating success/failure of the
    * operation. The possible return values are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_FAILED LIBSBML_OPERATION_FAILED @endlink
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
    */
   virtual int unsetTimeConversionFactor ();
 
@@ -433,8 +432,8 @@ public:
    *
    * @return integer value indicating success/failure of the
    * operation. The possible return values are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE @endlink
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}
    */
   virtual int setExtentConversionFactor (const std::string& id);
 
@@ -445,8 +444,8 @@ public:
    *
    * @return integer value indicating success/failure of the
    * operation. The possible return values are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_FAILED LIBSBML_OPERATION_FAILED @endlink
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
    */
   virtual int unsetExtentConversionFactor ();
 
@@ -521,11 +520,11 @@ public:
    *
    * @return integer value indicating success/failure of the
    * operation. The possible return values are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_LEVEL_MISMATCH LIBSBML_LEVEL_MISMATCH @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_VERSION_MISMATCH LIBSBML_VERSION_MISMATCH @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_PKG_VERSION_MISMATCH LIBSBML_VERSION_MISMATCH @endlink
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_INVALID_OBJECT, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_LEVEL_MISMATCH, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_VERSION_MISMATCH, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_PKG_VERSION_MISMATCH, OperationReturnValues_t}
    */
   int addDeletion (const Deletion* deletion);
 
@@ -589,7 +588,7 @@ public:
    * Returns the XML element name of
    * this SBML object.
    *
-   * @return the string of the name of this element.
+   * @return the name of this element, as a text string.
    */
   virtual const std::string& getElementName () const ;
 
@@ -606,7 +605,7 @@ public:
    * @copydetails doc_what_are_typecodes
    *
    * @return the SBML type code for this object:
-   * @link SBMLCompTypeCode_t#SBML_COMP_SUBMODEL SBML_COMP_SUBMODEL@endlink
+   * @sbmlconstant{SBML_COMP_SUBMODEL, SBMLCompTypeCode_t}
    *
    * @copydetails doc_warning_typecodes_not_unique
    *
@@ -694,9 +693,9 @@ public:
    *
    * @return an integer value indicating success/failure of the operation.
    * Possible return values from this function are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_FAILED LIBSBML_OPERATION_FAILED @endlink
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_INVALID_OBJECT, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
    * In this case, 'invalid object' means that this Submodel itself is invalid, and no Model can be instantiated from it.
    */
   virtual int instantiate();
@@ -708,9 +707,9 @@ public:
    *
    * @return an integer value indicating success/failure of the operation.
    * Possible return values from this function are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_FAILED LIBSBML_OPERATION_FAILED @endlink
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_INVALID_OBJECT, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
    * In this case, 'invalid object' means that this Submodel itself is invalid, and no Model can be instantiated from it.
    */
   virtual int performDeletions();
@@ -719,16 +718,16 @@ public:
   /**
    * Delete the element in question from the stored instantiated Model, and
    * replace all references to it with references to the replacement object.
-   * @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT @endlink
+   * @sbmlconstant{LIBSBML_INVALID_OBJECT, OperationReturnValues_t}
    * means that this Submodel itself or one of the passed-in objects are invalid.
-   * @link OperationReturnValues_t#LIBSBML_OPERATION_FAILED LIBSBML_OPERATION_FAILED @endlink
+   * @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
    * means that the routine failed for some othe reason.
    *
    * @return an integer value indicating success/failure of the operation.
    * Possible return values from this function are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_FAILED LIBSBML_OPERATION_FAILED @endlink
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_INVALID_OBJECT, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
    */
   virtual int replaceElement(SBase* toReplace, SBase* replacement);
 
@@ -846,197 +845,691 @@ LIBSBML_CPP_NAMESPACE_END
 LIBSBML_CPP_NAMESPACE_BEGIN
 BEGIN_C_DECLS
 
+/**
+ * Creates a new Submodel_t structure using the given SBML @p level
+ * and @p version values.
+ *
+ * @param level an unsigned int, the SBML Level to assign to this
+ * Submodel_t
+ * @param version an unsigned int, the SBML Version to assign to this
+ * Submodel_t
+ * @param pkgVersion an unsigned int, the SBML 'Qual' package Version to assign to this
+ * Submodel_t
+ *
+ * @return a pointer to the newly created Submodel_t structure.
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 Submodel_t *
 Submodel_create(unsigned int level, unsigned int version,
                 unsigned int pkgVersion);
 
 
+/**
+ * Frees the given Submodel_t structure.
+ *
+ * @param s the Submodel_t structure to free.
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 void
 Submodel_free(Submodel_t * s);
 
 
+/**
+ * Returns a copy of the given Submodel_t structure.
+ *
+ * @param s the Submodel_t structure to copy.
+ * 
+ * @return a (deep) copy of the Submodel_t.
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 Submodel_t *
 Submodel_clone(Submodel_t * s);
 
 
+/**
+ * Takes an Submodel_t structure and returns its identifier.
+ *
+ * @param s the Submodel_t structure whose identifier is sought
+ * 
+ * @return the identifier of the given Submodel_t, as a pointer to a string.
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 char *
 Submodel_getId(Submodel_t * s);
 
 
+/**
+ * Takes a Submodel_t structure and returns its name.
+ *
+ * @param s the Submodel_t whose name is sought.
+ *
+ * @return the name of the given Submodel_t, as a pointer to a string.
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 char *
 Submodel_getName(Submodel_t * s);
 
 
+/**
+ * Takes a Submodel_t structure and returns its modelRef.
+ *
+ * @param s the Submodel_t whose modelRef is sought.
+ *
+ * @return the modelRef of the given Submodel_t, as a pointer to a string.
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 char *
 Submodel_getModelRef(Submodel_t * s);
 
 
+/**
+ * Returns NULL, since "substanceConversionFactor" is not a part of the comp spec.
+ *
+ * @param s the Submodel_t whose substanceConversionFactor is sought.
+ *
+ * @return NULL
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 char *
 Submodel_getSubstanceConversionFactor(Submodel_t * s);
 
 
+/**
+ * Takes a Submodel_t structure and returns its timeConversionFactor.
+ *
+ * @param s the Submodel_t whose timeConversionFactor is sought.
+ *
+ * @return the timeConversionFactor of the given Submodel_t, as a pointer to a string.
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 char *
 Submodel_getTimeConversionFactor(Submodel_t * s);
 
 
+/**
+ * Takes a Submodel_t structure and returns its extentConversionFactor.
+ *
+ * @param s the Submodel_t whose extentConversionFactor is sought.
+ *
+ * @return the extentConversionFactor of the given Submodel_t, as a pointer to a string.
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 char *
 Submodel_getExtentConversionFactor(Submodel_t * s);
 
 
+/**
+ * Predicate returning @c true or @c false depending on whether the given
+ * Submodel_t structure's identifier is set.
+ *
+ * @param s the Submodel_t structure to query
+ * 
+ * @return @c non-zero (true) if the "id" attribute of the given
+ * Submodel_t structure is set, zero (false) otherwise.
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 int
 Submodel_isSetId(Submodel_t * s);
 
 
+/**
+ * Predicate returning @c true or @c false depending on whether the given
+ * Submodel_t structure's name is set.
+ *
+ * @param s the Submodel_t structure to query
+ * 
+ * @return @c non-zero (true) if the "name" attribute of the given
+ * Submodel_t structure is set, zero (false) otherwise.
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 int
 Submodel_isSetName(Submodel_t * s);
 
 
+/**
+ * Predicate returning @c true or @c false depending on whether the given
+ * Submodel_t structure's modelRef is set.
+ *
+ * @param s the Submodel_t structure to query
+ * 
+ * @return @c non-zero (true) if the "modelRef" attribute of the given
+ * Submodel_t structure is set, zero (false) otherwise.
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 int
 Submodel_isSetModelRef(Submodel_t * s);
 
 
+/**
+ * Returns @c false, since "substanceConversionFactor" is not a part of the comp spec.
+ *
+ * @param s the Submodel_t structure to query
+ * 
+ * @return @c 0 (false)
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 int
 Submodel_isSetSubstanceConversionFactor(Submodel_t * s);
 
 
+/**
+ * Predicate returning @c true or @c false depending on whether the given
+ * Submodel_t structure's timeConversionFactor is set.
+ *
+ * @param s the Submodel_t structure to query
+ * 
+ * @return @c non-zero (true) if the "timeConversionFactor" attribute of the given
+ * Submodel_t structure is set, zero (false) otherwise.
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 int
 Submodel_isSetTimeConversionFactor(Submodel_t * s);
 
 
+/**
+ * Predicate returning @c true or @c false depending on whether the given
+ * Submodel_t structure's extentConversionFactor is set.
+ *
+ * @param s the Submodel_t structure to query
+ * 
+ * @return @c non-zero (true) if the "extentConversionFactor" attribute of the given
+ * Submodel_t structure is set, zero (false) otherwise.
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 int
 Submodel_isSetExtentConversionFactor(Submodel_t * s);
 
 
+/**
+ * Assigns the identifier of an Submodel_t structure.
+ *
+ * This makes a copy of the string passed in the param @p sid.
+ *
+ * @param s the Submodel_t structure to set.
+ * @param sid the string to use as the identifier.
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}
+ *
+ * @note Using this function with an id of NULL is equivalent to
+ * unsetting the "id" attribute.
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 int
-Submodel_setId(Submodel_t * s, const char * id);
+Submodel_setId(Submodel_t * s, const char * sid);
 
 
+/**
+ * Sets the name of the given Submodel_t to a copy of @p name.
+ *
+ * @param s the Submodel_t structure to set
+ * @param name the name to assign to the given Submodel_t's "name" attribute.
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}
+ *
+ * @note Using this function with the name set to NULL is equivalent to
+ * unsetting the "name" attribute.
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 int
 Submodel_setName(Submodel_t * s, const char * name);
 
 
+/**
+ * Sets the modelRef of the given Submodel_t to a copy of @p modelRef.
+ *
+ * @param s the Submodel_t structure to set
+ * @param modelRef the modelRef to assign to the given Submodel_t's "modelRef" attribute.
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}
+ *
+ * @note Using this function with the name set to NULL is equivalent to
+ * unsetting the "modelRef" attribute.
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 int
 Submodel_setModelRef(Submodel_t * s, const char * modelRef);
 
 
+/**
+ * Automatically fails, since "substanceConversionFactor" is not a part of the comp spec.
+ *
+ * @param s the Submodel_t structure to set
+ * @param substanceConversionFactor the substanceConversionFactor to ignore
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible value
+ * returned by this function is:
+ * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 int
-Submodel_setSubstanceConversionFactor(Submodel_t * s, const char * timeConversionFactor);
+Submodel_setSubstanceConversionFactor(Submodel_t * s, const char * substanceConversionFactor);
 
 
+/**
+ * Sets the timeConversionFactor of the given Submodel_t to a copy of @p timeConversionFactor.
+ *
+ * @param s the Submodel_t structure to set
+ * @param timeConversionFactor the timeConversionFactor to assign to the given Submodel_t's "timeConversionFactor" attribute.
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}
+ *
+ * @note Using this function with the name set to NULL is equivalent to
+ * unsetting the "timeConversionFactor" attribute.
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 int
 Submodel_setTimeConversionFactor(Submodel_t * s, const char * timeConversionFactor);
 
 
+/**
+ * Sets the extentConversionFactor of the given Submodel_t to a copy of @p extentConversionFactor.
+ *
+ * @param s the Submodel_t structure to set
+ * @param extentConversionFactor the extentConversionFactor to assign to the given Submodel_t's "extentConversionFactor" attribute.
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}
+ *
+ * @note Using this function with the name set to NULL is equivalent to
+ * unsetting the "extentConversionFactor" attribute.
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 int
 Submodel_setExtentConversionFactor(Submodel_t * s, const char * extentConversionFactor);
 
 
+/**
+ * Unsets the "id" attribute of the given Submodel_t structure.
+ *
+ * @param s the Submodel_t structure to unset
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 int
 Submodel_unsetId(Submodel_t * s);
 
 
+/**
+ * Unsets the "name" attribute of the given Submodel_t structure.
+ *
+ * @param s the Submodel_t structure to unset
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 int
 Submodel_unsetName(Submodel_t * s);
 
 
+/**
+ * Unsets the "modelRef" attribute of the given Submodel_t structure.
+ *
+ * @param s the Submodel_t structure to unset
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 int
 Submodel_unsetModelRef(Submodel_t * s);
 
 
+/**
+ * Automatically fails, since "substanceConversionFactor" is not a part of the comp spec.
+ *
+ * @param s the Submodel_t structure to unset
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible value
+ * returned by this function is:
+ * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 int
 Submodel_unsetSubstanceConversionFactor(Submodel_t * s);
 
 
+/**
+ * Unsets the "timeConversionFactor" attribute of the given Submodel_t structure.
+ *
+ * @param s the Submodel_t structure to unset
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 int
 Submodel_unsetTimeConversionFactor(Submodel_t * s);
 
 
+/**
+ * Unsets the "extentConversionFactor" attribute of the given Submodel_t structure.
+ *
+ * @param s the Submodel_t structure to unset
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 int
 Submodel_unsetExtentConversionFactor(Submodel_t * s);
 
 
+/**
+ * Appends a copy of the given Deletion_t structure to the given Submodel_t
+ * structure.
+ *
+ * @param s the Submodel_t structure to which the Deletion_t should be
+ * added
+ *
+ * @param d a Deletion_t structure to add
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_LEVEL_MISMATCH, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_VERSION_MISMATCH, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_PKG_VERSION_MISMATCH, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_DUPLICATE_OBJECT_ID, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 int
 Submodel_addDeletion(Submodel_t * s, Deletion_t * d);
 
 
+/**
+ * Creates a new, empty Deletion_t structure, adds it to the given
+ * Submodel_t, and returns the Deletion_t.
+ *
+ * @param s the Submodel_t structure to which the Deletion_t should be
+ * added
+ *
+ * @return the newly-created empty Deletion_t.
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 Deletion_t *
 Submodel_createDeletion(Submodel_t * s);
 
 
+/**
+ * Get the list of Deletion_t structures from the given Submodel_t
+ * structure.
+ *
+ * @param s the Submodel_t structure to use.
+ *
+ * @return the list of CHILDTYPEs for the given Submodel_t.
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 ListOf_t *
 Submodel_getListOfDeletions(Submodel_t * s) ;
 
 
+/**
+ * Return a specific Deletion_t structure of the given Submodel_t.
+ *
+ * @param s the Submodel_t structure to use
+ *
+ * @param n an integer, the index of the Deletion_t structure to return
+ * 
+ * @return the nth Deletion_t of the given Submodel_t, or @c NULL if no such Deletion_t exists.
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 Deletion_t *
 Submodel_getDeletion(Submodel_t * s, unsigned int n);
 
 
+/**
+ * Return the Deletion_t indicated by the given @p sid.
+ *
+ * @param s the Submodel_t structure to use
+ *
+ * @param sid a string, the identifier of the
+ * Deletion_t is being sought.
+ *
+ * @return the Deletion_t for the given variable, or @c NULL if no such
+ * Deletion_t exits.
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 Deletion_t *
 Submodel_getDeletionById(Submodel_t * s, const char * sid);
 
 
+/**
+ * Returns the number of EventAssignment_t structures attached to the given
+ * Submodel_t.
+ *
+ * @param s the Submodel_t structure to use
+ * 
+ * @return the number of EventAssignment_t structures in the given Submodel_t.
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 unsigned int
 Submodel_getNumDeletions(Submodel_t * s);
 
 
+/**
+ * Removes the nth Deletion_t structure from the given Submodel_t structure and
+ * returns a pointer to it.
+ *
+ * * The caller owns the returned structure and is responsible for deleting it.
+ *
+ * @param s the Submodel_t structure
+ * @param n the integer index of the Deletion_t sought
+ *
+ * @return the Deletion_t structure removed.  As mentioned above, 
+ * the caller owns the returned item. @c NULL is returned if the given index 
+ * is out of range.
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 Deletion_t *
 Submodel_removeDeletion(Submodel_t * s, unsigned int n);
 
 
+/**
+ * Removes the Deletion_t structure with the given @p sid
+ * from the given Submodel_t structure and returns a pointer to it.
+ *
+ * * The caller owns the returned structure and is responsible for deleting it.
+ *
+ * @param s the Submodel_t structure
+ * @param sid the string of the "id" attribute of the Deletion_t sought
+ *
+ * @return the Deletion_t structure removed.  As mentioned above, the 
+ * caller owns the returned structure. @c NULL is returned if no Deletion_t
+ * structure with the "id" attribute exists in the given Submodel_t structure.
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 Deletion_t *
 Submodel_removeDeletionById(Submodel_t * s, const char * sid);
 
 
+/**
+  * Predicate returning @c true or @c false depending on whether
+  * all the required attributes for the given Submodel_t structure
+  * have been set.
+  *
+  * @note The required attributes for a Submodel_t structure are:
+  * @li useValuesfromTriggerTime ( L3 onwards )
+  *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 int
 Submodel_hasRequiredAttributes(Submodel_t * s);
 
 
+/**
+  * Predicate returning @c true or @c false depending on whether
+  * all the required elements for the given Submodel_t structure
+  * have been set.
+  *
+  * @note The required elements for an Submodel_t structure are:
+  * @li trigger
+  * @li listOfEventAssignments (requirement removed in L3)
+  *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 int
 Submodel_hasRequiredElements(Submodel_t * s);
 
 
+/**
+ * Return the Submodel_t indicated by the given @p sid.
+ *
+ * @param lo the ListOf_t structure to use
+ *
+ * @param sid a string, the identifier of the
+ * Submodel_t is being sought.
+ *
+ * @return the Submodel_t for the given variable, or @c NULL if no such
+ * Submodel_t exits.
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 Submodel_t *
 ListOfSubmodels_getById(ListOf_t * lo, const char * sid);
 
 
+/**
+ * Removes the Submodel_t structure with the given @p sid
+ * from the given ListOf_t structure and returns a pointer to it.
+ *
+ * * The caller owns the returned structure and is responsible for deleting it.
+ *
+ * @param lo the ListOf_t structure
+ * @param sid the string of the "id" attribute of the Submodel_t sought
+ *
+ * @return the Submodel_t structure removed.  As mentioned above, the 
+ * caller owns the returned structure. @c NULL is returned if no Submodel_t
+ * structure with the "id" attribute exists in the given ListOf_t structure.
+ *
+ * @memberof Submodel_t
+ */
 LIBSBML_EXTERN
 Submodel_t *
 ListOfSubmodels_removeById(ListOf_t * lo, const char * sid);
