@@ -76,7 +76,7 @@ SBMLConverter(orig)
 {
 }
 
-SBMLConverter* 
+CompFlatteningConverter* 
 CompFlatteningConverter::clone() const
 {
   return new CompFlatteningConverter(*this);
@@ -197,9 +197,9 @@ CompFlatteningConverter::convert()
     bool originalOverrideFlag = plugin->getOverrideCompFlattening();
     plugin->setOverrideCompFlattening(true);
     
-    unsigned int errors = mDocument->checkConsistency();
+    mDocument->checkConsistency();
 
-    errors = mDocument->getErrorLog()
+    unsigned int errors = mDocument->getErrorLog()
                         ->getNumFailsWithSeverity(LIBSBML_SEV_ERROR);
     
     // take out the error about a requiredpackage
