@@ -6,9 +6,16 @@
  *<!---------------------------------------------------------------------------
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
- *
- * Copyright 2009-2013 California Institute of Technology.
  * 
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ * 
+ * Copyright (C) 2009-2013 jointly by the following organizations: 
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *
  * This library is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.  A copy of the license agreement is provided
@@ -17,13 +24,14 @@
  *------------------------------------------------------------------------- -->
  *
  * @class FluxObjective
- * @sbmlbrief{fbc} Implementation of the 'fbc' package %FluxObjective
- * construct.
+ * @sbmlbrief{fbc} An objective function for a flux.
  *
- * An integral component in a complete description of a steady-state model is the so-called 'objective function' which generally consists of a linear combination of model variables (fluxes) and a sense (direction). In the FBC package this concept is succinctly captured in the Objective class.
- * <!-- leave this next break as-is to work around some doxygen bug -->
- */ 
-
+ * An integral component in a complete description of a steady-state model is
+ * the so-called <em>objective function</em>, which generally consists of a
+ * linear combination of model variables (fluxes) and a sense (direction). In
+ * the SBML Level&nbsp;3 FBC package, this concept is succinctly captured in
+ * the Objective class.
+ */
 
 #ifndef FluxObjective_H__
 #define FluxObjective_H__
@@ -110,8 +118,8 @@ public:
    *
    * @return integer value indicating success/failure of the
    * operation. The possible return values are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE @endlink
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}
    */
   virtual int setId (const std::string& id);
   
@@ -121,8 +129,8 @@ public:
    *
    * @return integer value indicating success/failure of the
    * operation. The possible return values are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_FAILED LIBSBML_OPERATION_FAILED @endlink
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
    */
   virtual int unsetId ();
   
@@ -150,8 +158,8 @@ public:
    *
    * @return integer value indicating success/failure of the
    * operation. The possible return values are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE @endlink
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}
    */
   virtual int setName (const std::string& name);
   
@@ -161,8 +169,8 @@ public:
    *
    * @return integer value indicating success/failure of the
    * operation. The possible return values are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_FAILED LIBSBML_OPERATION_FAILED @endlink
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
    */
   virtual int unsetName ();
 
@@ -191,8 +199,8 @@ public:
    *
    * @return integer value indicating success/failure of the
    * operation. The possible return values are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE @endlink
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}
    */
   virtual int setReaction (const std::string& reaction);
 
@@ -202,8 +210,8 @@ public:
    *
    * @return integer value indicating success/failure of the
    * operation. The possible return values are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_FAILED LIBSBML_OPERATION_FAILED @endlink
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
    */
   virtual int unsetReaction ();
 
@@ -233,8 +241,8 @@ public:
    *
    * @return integer value indicating success/failure of the
    * operation. The possible return values are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE @endlink
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}
    */
   virtual int setCoefficient (const double coefficient);
 
@@ -244,23 +252,14 @@ public:
    *
    * @return integer value indicating success/failure of the
    * operation. The possible return values are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_FAILED LIBSBML_OPERATION_FAILED @endlink
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
    */
   virtual int unsetCoefficient ();
 
 
   /**
-   * Renames all the @c SIdRef attributes on this element, including any
-   * found in MathML content (if such exists).
-   *
-   * This method works by looking at all attributes and (if appropriate)
-   * mathematical formulas, comparing the identifiers to the value of @p
-   * oldid.  If any matches are found, the matching identifiers are replaced
-   * with @p newid.  The method does @em not descend into child elements.
-   *
-   * @param oldid the old identifier
-   * @param newid the new identifier
+   * @copydoc doc_renamesidref_common
    */
    virtual void renameSIdRefs(const std::string& oldid, const std::string& newid);
 
@@ -269,7 +268,7 @@ public:
    * Returns the XML element name of
    * this SBML object.
    *
-   * @return the string of the name of this element.
+   * @return the name of this element, as a text string.
    */
   virtual const std::string& getElementName () const ;
 
@@ -288,7 +287,7 @@ public:
    * @copydetails doc_what_are_typecodes
    *
    * @return the SBML type code for this object:
-   * @link SBMLFbcTypeCode_t#SBML_FBC_FLUXOBJECTIVE SBML_FBC_FLUXOBJECTIVE@endlink
+   * @sbmlconstant{SBML_FBC_FLUXOBJECTIVE, SBMLFbcTypeCode_t}
    *
    * @copydetails doc_warning_typecodes_not_unique
    *
@@ -377,8 +376,7 @@ protected:
 
 /**
  * @class ListOfFluxObjectives
- * @sbmlbrief{fbc} Implementation of the 'fbc' package %ListOfFluxObjectives
- * construct.
+ * @sbmlbrief{fbc} A list of FluxObjectives.
  * 
  * The ListOfFluxObjectives is a container for the FluxObjective elements of a Model annotation.
  * 
@@ -506,7 +504,7 @@ public:
    * @copydetails doc_what_are_typecodes
    *
    * @return the SBML type code for objects contained in this list:
-   * @link SBMLTypeCode_t#SBML_FBC_FLUXOBJECTIVE SBML_FBC_FLUXOBJECTIVE@endlink (default).
+   * @sbmlconstant{SBML_FBC_FLUXOBJECTIVE, SBMLTypeCode_t} (default).
    *
    * @see getElementName()
    * @see getPackageName()
@@ -517,7 +515,7 @@ public:
    * Returns the XML element name of
    * this SBML object.
    *
-   * @return the string of the name of this element.
+   * @return the name of this element, as a text string.
    */
   virtual const std::string& getElementName () const;
 
@@ -563,93 +561,314 @@ LIBSBML_CPP_NAMESPACE_END
 LIBSBML_CPP_NAMESPACE_BEGIN
 BEGIN_C_DECLS
 
-/*
- * C API will be added here.
+/**
+ * Creates a new FluxObjective_t structure using the given SBML @p level
+ * and @p version values.
+ *
+ * @param level an unsigned int, the SBML Level to assign to this
+ * FluxObjective_t
+ * @param version an unsigned int, the SBML Version to assign to this
+ * FluxObjective_t
+ * @param pkgVersion an unsigned int, the SBML 'Qual' package Version to assign to this
+ * FluxObjective_t
+ *
+ * @return a pointer to the newly created FluxObjective_t structure.
+ *
+ * @memberof FluxObjective_t
  */
 LIBSBML_EXTERN
 FluxObjective_t *
-FluxObjective_create(unsigned int level, unsigned int version, unsigned int pkgversion);
+FluxObjective_create(unsigned int level, unsigned int version, unsigned int pkgVersion);
 
 
 
+/**
+ * Takes an FluxObjective_t structure and returns its identifier.
+ *
+ * @param fo the FluxObjective_t structure whose identifier is sought
+ * 
+ * @return the identifier of the given FluxObjective_t, as a pointer to a string.
+ *
+ * @memberof FluxObjective_t
+ */
 LIBSBML_EXTERN
 const char *
-FluxObjective_getId(FluxObjective_t * fb);
+FluxObjective_getId(FluxObjective_t * fo);
 
 
+/**
+ * Predicate returning @c true or @c false depending on whether the given
+ * FluxObjective_t structure's identifier is set.
+ *
+ * @param fo the FluxObjective_t structure to query
+ * 
+ * @return @c non-zero (true) if the "id" attribute of the given
+ * FluxObjective_t structure is set, zero (false) otherwise.
+ *
+ * @memberof FluxObjective_t
+ */
 LIBSBML_EXTERN
 int
-FluxObjective_isSetId(FluxObjective_t * fb);
+FluxObjective_isSetId(FluxObjective_t * fo);
 
 
+/**
+ * Assigns the identifier of an FluxObjective_t structure.
+ *
+ * This makes a copy of the string passed in the param @p sid.
+ *
+ * @param fo the FluxObjective_t structure to set.
+ * @param sid the string to use as the identifier.
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}
+ *
+ * @note Using this function with an id of NULL is equivalent to
+ * unsetting the "id" attribute.
+ *
+ * @memberof FluxObjective_t
+ */
 LIBSBML_EXTERN
 int
-FluxObjective_setId(FluxObjective_t * fb, const char * id);
+FluxObjective_setId(FluxObjective_t * fo, const char * sid);
 
 
+/**
+ * Unsets the "id" attribute of the given FluxObjective_t structure.
+ *
+ * @param fo the FluxObjective_t structure to unset
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+ *
+ * @memberof FluxObjective_t
+ */
 LIBSBML_EXTERN
 int
-FluxObjective_unsetId(FluxObjective_t * fb);
+FluxObjective_unsetId(FluxObjective_t * fo);
 
+/**
+ * Takes a FluxObjective_t structure and returns its name.
+ *
+ * @param fo the FluxObjective_t whose name is sought.
+ *
+ * @return the name of the given FluxObjective_t, as a pointer to a string.
+ *
+ * @memberof FluxObjective_t
+ */
 LIBSBML_EXTERN
 const char *
-FluxObjective_getName(FluxObjective_t * fb);
+FluxObjective_getName(FluxObjective_t * fo);
 
 
+/**
+ * Predicate returning @c true or @c false depending on whether the given
+ * FluxObjective_t structure's name is set.
+ *
+ * @param fo the FluxObjective_t structure to query
+ * 
+ * @return @c non-zero (true) if the "name" attribute of the given
+ * FluxObjective_t structure is set, zero (false) otherwise.
+ *
+ * @memberof FluxObjective_t
+ */
 LIBSBML_EXTERN
 int
-FluxObjective_isSetName(FluxObjective_t * fb);
+FluxObjective_isSetName(FluxObjective_t * fo);
 
 
+/**
+ * Sets the name of the given FluxObjective_t to a copy of @p name.
+ *
+ * @param fo the FluxObjective_t structure to set
+ * @param name the name to assign to the given FluxObjective_t's "name" attribute.
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}
+ *
+ * @note Using this function with the name set to NULL is equivalent to
+ * unsetting the "name" attribute.
+ *
+ * @memberof FluxObjective_t
+ */
 LIBSBML_EXTERN
 int
-FluxObjective_setName(FluxObjective_t * fb, const char * name);
+FluxObjective_setName(FluxObjective_t * fo, const char * name);
 
 
+/**
+ * Unsets the "name" attribute of the given FluxObjective_t structure.
+ *
+ * @param fo the FluxObjective_t structure to unset
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+ *
+ * @memberof FluxObjective_t
+ */
 LIBSBML_EXTERN
 int
-FluxObjective_unsetName(FluxObjective_t * fb);
+FluxObjective_unsetName(FluxObjective_t * fo);
 
 
 
+/**
+ * Takes a FluxObjective_t structure and returns its reaction.
+ *
+ * @param fo the FluxObjective_t whose reaction is sought.
+ *
+ * @return the reaction of the given FluxObjective_t, as a pointer to a string.
+ *
+ * @memberof FluxObjective_t
+ */
 LIBSBML_EXTERN
 const char *
-FluxObjective_getReaction(FluxObjective_t * flux);
+FluxObjective_getReaction(FluxObjective_t * fo);
 
 
+/**
+ * Predicate returning @c true or @c false depending on whether the given
+ * FluxObjective_t structure's reaction is set.
+ *
+ * @param fo the FluxObjective_t structure to query
+ * 
+ * @return @c non-zero (true) if the "reaction" attribute of the given
+ * FluxObjective_t structure is set, zero (false) otherwise.
+ *
+ * @memberof FluxObjective_t
+ */
 LIBSBML_EXTERN
 int
-FluxObjective_isSetReaction(FluxObjective_t * flux);
+FluxObjective_isSetReaction(FluxObjective_t * fo);
 
 
+/**
+ * Sets the reaction of the given FluxObjective_t to a copy of @p reaction.
+ *
+ * @param fo the FluxObjective_t structure to set
+ * @param reaction the reaction to assign to the given FluxObjective_t's "reaction" attribute.
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}
+ *
+ * @note Using this function with the name set to NULL is equivalent to
+ * unsetting the "reaction" attribute.
+ *
+ * @memberof FluxObjective_t
+ */
 LIBSBML_EXTERN
 int
-FluxObjective_setReaction(FluxObjective_t * flux, const char * reaction);
+FluxObjective_setReaction(FluxObjective_t * fo, const char * reaction);
 
 
+/**
+ * Unsets the "reaction" attribute of the given FluxObjective_t structure.
+ *
+ * @param fo the FluxObjective_t structure to unset
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+ *
+ * @memberof FluxObjective_t
+ */
 LIBSBML_EXTERN
 int
-FluxObjective_unsetReaction(FluxObjective_t * flux);
+FluxObjective_unsetReaction(FluxObjective_t * fo);
 
 
+/**
+ * Takes a FluxObjective_t structure and returns its coefficient.
+ *
+ * @param fo the FluxObjective_t whose coefficient is sought.
+ *
+ * @return the coefficient attribute of the given FluxObjective_t, as a @c double.
+ *
+ * @memberof FluxObjective_t
+ */
 LIBSBML_EXTERN
 double
-FluxObjective_getCoefficient(FluxObjective_t * flux);
+FluxObjective_getCoefficient(FluxObjective_t * fo);
 
 
+/**
+ * Predicate returning @c true or @c false depending on whether the given
+ * FluxObjective_t structure's coefficient is set.
+ *
+ * @param fo the FluxObjective_t structure to query
+ * 
+ * @return @c non-zero (true) if the "coefficient" attribute of the given
+ * FluxObjective_t structure is set, zero (false) otherwise.
+ *
+ * @memberof FluxObjective_t
+ */
 LIBSBML_EXTERN
 int
-FluxObjective_isSetCoefficient(FluxObjective_t * flux);
+FluxObjective_isSetCoefficient(FluxObjective_t * fo);
 
 
+/**
+ * Sets the "coefficient" attribute of the given FluxObjective_t
+ * structure.
+ *
+ * @param fo the FluxObjective_t structure
+ * 
+ * @param coefficient the value of coefficient to assign to the "coefficient" attribute
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_UNEXPECTED_ATTRIBUTE, OperationReturnValues_t}
+ *
+ * @memberof FluxObjective_t
+ */
 LIBSBML_EXTERN
 int
-FluxObjective_setCoefficient(FluxObjective_t * flux, double coeff);
+FluxObjective_setCoefficient(FluxObjective_t * fo, double coefficient);
 
 
+/**
+ * Unsets the "coefficient" attribute of the given FluxObjective_t structure.
+ *
+ * @param fo the FluxObjective_t structure to unset
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+ *
+ * @memberof FluxObjective_t
+ */
 LIBSBML_EXTERN
 int
-FluxObjective_unsetCoefficient(FluxObjective_t * flux);
+FluxObjective_unsetCoefficient(FluxObjective_t * fo);
 
 
 
