@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ * 
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2004-2008 by European Media Laboratories Research gGmbH,
  *     Heidelberg, Germany
@@ -685,11 +690,8 @@ XMLNode CubicBezier::toXML() const
 
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
+/** @cond doxygenIgnored */
 
-/**
- * Creates a CubicBezier and returns the pointer.
- */
 LIBSBML_EXTERN
 CubicBezier_t *
 CubicBezier_create (void)
@@ -698,9 +700,6 @@ CubicBezier_create (void)
 }
 
 
-/**
- * Creates a CubicBezier with the given points and returns the pointer.
- */
 LIBSBML_EXTERN
 CubicBezier_t *
 CubicBezier_createWithPoints (const Point_t *start, const Point_t *base1,
@@ -711,10 +710,6 @@ CubicBezier_createWithPoints (const Point_t *start, const Point_t *base1,
 }
 
 
-/**
- * Creates a CubicBezier with the given coordinates and returns the
- * pointer.
- */
 LIBSBML_EXTERN
 CubicBezier_t *
 CubicBezier_createWithCoordinates (double x1, double y1, double z1,
@@ -737,9 +732,6 @@ CubicBezier_createWithCoordinates (double x1, double y1, double z1,
 }
 
 
-/**
- * Creates a CubicBezier object from a template.
- */
 LIBSBML_EXTERN
 CubicBezier_t *
 CubicBezier_createFrom (const CubicBezier_t *temp)
@@ -748,9 +740,6 @@ CubicBezier_createFrom (const CubicBezier_t *temp)
 }
 
 
-/**
- * Frees the memory for the cubic bezier.
- */
 LIBSBML_EXTERN
 void
 CubicBezier_free (CubicBezier_t *cb)
@@ -759,9 +748,6 @@ CubicBezier_free (CubicBezier_t *cb)
 }
 
 
-/**
- * Initializes start point with a copy of the given point.
- */
 LIBSBML_EXTERN
 void
 CubicBezier_setStart (CubicBezier_t *cb, const Point_t *start)
@@ -770,9 +756,6 @@ CubicBezier_setStart (CubicBezier_t *cb, const Point_t *start)
 }
 
 
-/**
- * Returns the starting point of the curve.
- */ 
 LIBSBML_EXTERN
 Point_t *
 CubicBezier_getStart (CubicBezier_t *cb)
@@ -781,9 +764,6 @@ CubicBezier_getStart (CubicBezier_t *cb)
 }
 
 
-/**
- * Initializes end point with a copy of the given point.
- */
 LIBSBML_EXTERN
 void
 CubicBezier_setEnd (CubicBezier_t *cb, const Point_t *end)
@@ -792,9 +772,6 @@ CubicBezier_setEnd (CubicBezier_t *cb, const Point_t *end)
 }
 
 
-/**
- * Returns the end point of the curve.
- */ 
 LIBSBML_EXTERN
 Point_t *
 CubicBezier_getEnd (CubicBezier_t *cb)
@@ -803,69 +780,55 @@ CubicBezier_getEnd (CubicBezier_t *cb)
 }
 
 
-/**
- * Initializes the first base point with a copy of the given point.
- */
 LIBSBML_EXTERN
 void
 CubicBezier_setBasePoint1 (CubicBezier_t *cb, const Point_t *point)
 {
+  if (cb == NULL) return;
   cb->setBasePoint1(point);
 }
 
 
-/**
- * Returns the first base point of the curve (the one closer to the
- * starting point).
- */ 
 LIBSBML_EXTERN
 Point_t *
 CubicBezier_getBasePoint1 (CubicBezier_t *cb)
 {
+  if (cb == NULL) return NULL;
   return cb->getBasePoint1();
 }
 
 
-/**
- * Initializes the second base point with a copy of the given point.
- */
 LIBSBML_EXTERN
 void
 CubicBezier_setBasePoint2 (CubicBezier_t *cb, const Point_t *point)
 {
+  if (cb == NULL) return;
   cb->setBasePoint2(point );
 }
 
 
-/**
- * Returns the second base point of the curve (the one closer to the
- * starting point).
- */ 
 LIBSBML_EXTERN
 Point_t *
 CubicBezier_getBasePoint2 (CubicBezier_t *cb)
 {
+  if (cb == NULL) return NULL;
   return cb->getBasePoint2();
 }
 
 
-/**
- * Calls initDefaults from LineSegment.
- */ 
 LIBSBML_EXTERN
 void
 CubicBezier_initDefaults (CubicBezier_t *cb)
 {
+  if (cb == NULL) return;
   cb->initDefaults();
 }
 
-/**
- * @return a (deep) copy of this CubicBezier.
- */
 LIBSBML_EXTERN
 CubicBezier_t *
 CubicBezier_clone (const CubicBezier_t *m)
 {
+  if (m == NULL) return NULL;
   return static_cast<CubicBezier*>( m->clone() );
 }
 
