@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ * 
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2004-2008 by European Media Laboratories Research gGmbH,
  *     Heidelberg, Germany
@@ -327,6 +332,7 @@ Curve::createLineSegment ()
   LineSegment* ls = new LineSegment(layoutns);
 
   this->mCurveSegments.appendAndOwn(ls);
+  delete layoutns;
   return ls;
 }
 
@@ -341,6 +347,7 @@ CubicBezier* Curve::createCubicBezier ()
   CubicBezier* cb = new CubicBezier(layoutns);
 
   this->mCurveSegments.appendAndOwn(cb);
+  delete layoutns;
   return cb;
 }
 
@@ -618,6 +625,7 @@ ListOfLineSegments::createObject (XMLInputStream& stream)
 			getErrorLog()->logPackageError("layout", LayoutXsiTypeSyntax,
 			               getPackageVersion(), getLevel(), getVersion());
     }
+    delete layoutns;
   }
   
   if(object) appendAndOwn(object);
@@ -663,11 +671,8 @@ Curve::accept (SBMLVisitor& v) const
 
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
+/** @cond doxygenIgnored */
 
-/**
- * Creates a new curve and returns the pointer to it.
- */
 LIBSBML_EXTERN
 Curve_t *
 Curve_create (void)
@@ -676,9 +681,6 @@ Curve_create (void)
 }
 
 
-/**
- * Creates a new Curve object from a template.
- */
 LIBSBML_EXTERN
 Curve_t *
 Curve_createFrom (const Curve_t *temp)
@@ -687,9 +689,6 @@ Curve_createFrom (const Curve_t *temp)
 }
 
 
-/**
- * Frees the memory taken by the Curve.
- */
 LIBSBML_EXTERN
 void
 Curve_free (Curve_t *c)
@@ -698,91 +697,74 @@ Curve_free (Curve_t *c)
 }
 
 
-/**
- * Adds a LineSegment.
- */
 LIBSBML_EXTERN
 void
 Curve_addCurveSegment (Curve_t *c, LineSegment_t *ls)
 {
+  if (c == NULL) return;
   c->addCurveSegment(ls);
 }
 
 
-/**
- * Returns the number of line segments.
- */
 LIBSBML_EXTERN
 unsigned int
 Curve_getNumCurveSegments (const Curve_t *c)
 {
+  if (c == NULL) return 0;
   return c->getNumCurveSegments();
 }
 
 
-/**
- * Returns the line segment with the given index.
- */
 LIBSBML_EXTERN
 LineSegment_t *
 Curve_getCurveSegment (const Curve_t *c, unsigned int index)
 {
+  if (c == NULL) return NULL;
   return const_cast<LineSegment*>(c->getCurveSegment(index));
 }
 
 
-/**
- * Returns the ListOf object that holds all the curve segments.
- */ 
 LIBSBML_EXTERN
 ListOf_t *
 Curve_getListOfCurveSegments (Curve_t *c)
 {
+  if (c == NULL) return NULL;
   return c->getListOfCurveSegments();
 }
 
 
-/**
- * Does nothing since no defaults are defined for Curve.
- */ 
 LIBSBML_EXTERN
 void
 Curve_initDefaults (Curve_t *c)
 {
+  if (c == NULL) return;
   c->initDefaults();
 }
 
 
-/**
- * Creates a new LineSegment and adds it to the end of the list.  A pointer
- * to the new LineSegment object is returned.
- */
 LIBSBML_EXTERN
 LineSegment_t *
 Curve_createLineSegment (Curve_t *c)
 {
+  if (c == NULL)  return NULL;
   return c->createLineSegment();
 }
 
 
-/**
- * Creates a new CubicBezier and adds it to the end of the list.  A pointer
- * to the new CubicBezier object is returned.
- */
 LIBSBML_EXTERN
 CubicBezier_t *
 Curve_createCubicBezier (Curve_t *c)
 {
+  if (c == NULL) return NULL;
   return c->createCubicBezier();
 }
 
-/**
- * @return a (deep) copy of this Curve.
- */
+
 LIBSBML_EXTERN
 Curve_t *
 Curve_clone (const Curve_t *m)
 {
+  if (m == NULL) return NULL;
   return static_cast<Curve*>( m->clone() );
 }
 
