@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ * 
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2004-2008 by European Media Laboratories Research gGmbH,
  *     Heidelberg, Germany
@@ -1264,6 +1269,7 @@ Layout::createCompartmentGlyph ()
   CompartmentGlyph* p = new CompartmentGlyph(layoutns);
 
   this->mCompartmentGlyphs.appendAndOwn(p);
+  delete layoutns;
   return p;
 }
 
@@ -1279,6 +1285,7 @@ Layout::createSpeciesGlyph ()
   SpeciesGlyph* p = new SpeciesGlyph(layoutns);
 
   this->mSpeciesGlyphs.appendAndOwn(p);
+  delete layoutns;
   return p;
 }
 
@@ -1294,6 +1301,7 @@ Layout::createReactionGlyph ()
   ReactionGlyph* p = new ReactionGlyph(layoutns);
 
   this->mReactionGlyphs.appendAndOwn(p);  
+  delete layoutns;
   return p;
 }
 
@@ -1308,6 +1316,7 @@ Layout::createGeneralGlyph ()
   GeneralGlyph* g = new GeneralGlyph(layoutns);
 
   this->mAdditionalGraphicalObjects.appendAndOwn(g);
+  delete layoutns;
   return g;
 }
 
@@ -1323,6 +1332,7 @@ Layout::createTextGlyph ()
   TextGlyph* p = new TextGlyph(layoutns);
 
   this->mTextGlyphs.appendAndOwn(p);
+  delete layoutns;
   return p;
 }
 
@@ -1339,6 +1349,7 @@ Layout::createAdditionalGraphicalObject ()
   GraphicalObject* p = new GraphicalObject(layoutns);
 
   this->mAdditionalGraphicalObjects.appendAndOwn(p);
+  delete layoutns;
   return p;
 }
 
@@ -1915,7 +1926,7 @@ ListOfLayouts::createObject (XMLInputStream& stream)
     LAYOUT_CREATE_NS(layoutns,this->getSBMLNamespaces());
     object = new Layout(layoutns);
     appendAndOwn(object);
-    //mItems.push_back(object);
+    delete layoutns;
   }
 
   return object;
@@ -1931,11 +1942,12 @@ ListOfLayouts::writeXMLNS (XMLOutputStream& stream) const
 
   std::string prefix = getPrefix();
 
-    if (getNamespaces()->hasURI(LayoutExtension::getXmlnsL3V1V1()))
+    XMLNamespaces* thisxmlns = getNamespaces();
+    if (thisxmlns && thisxmlns->hasURI(LayoutExtension::getXmlnsL3V1V1()))
     {
       xmlns.add(LayoutExtension::getXmlnsL3V1V1(),prefix);
     }
-    if (getNamespaces()->hasURI(LayoutExtension::getXmlnsL2()))
+    if (thisxmlns && thisxmlns->hasURI(LayoutExtension::getXmlnsL2()))
     {
       xmlns.add(LayoutExtension::getXmlnsL2(),prefix);
     }
@@ -2086,6 +2098,7 @@ ListOfCompartmentGlyphs::createObject (XMLInputStream& stream)
     LAYOUT_CREATE_NS(layoutns,this->getSBMLNamespaces());
     object = new CompartmentGlyph(layoutns);
     appendAndOwn(object);
+    delete layoutns;
 //    mItems.push_back(object);
   }
 
@@ -2237,6 +2250,7 @@ ListOfSpeciesGlyphs::createObject (XMLInputStream& stream)
     LAYOUT_CREATE_NS(layoutns,this->getSBMLNamespaces());
     object = new SpeciesGlyph(layoutns);
     appendAndOwn(object);
+    delete layoutns;
 //    mItems.push_back(object);
   }
 
@@ -2385,6 +2399,7 @@ ListOfReactionGlyphs::createObject (XMLInputStream& stream)
     LAYOUT_CREATE_NS(layoutns,this->getSBMLNamespaces());
     object = new ReactionGlyph(layoutns);
     appendAndOwn(object);
+    delete layoutns;
 //    mItems.push_back(object);
   }
 
@@ -2533,6 +2548,7 @@ ListOfTextGlyphs::createObject (XMLInputStream& stream)
     LAYOUT_CREATE_NS(layoutns,this->getSBMLNamespaces());
     object = new TextGlyph(layoutns);
     appendAndOwn(object);
+    delete layoutns;
 //    mItems.push_back(object);
   }
 
@@ -2553,11 +2569,8 @@ XMLNode ListOfTextGlyphs::toXML() const
 
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
+/** @cond doxygenIgnored */
 
-/**
- * Creates a new Layout and returns a pointer to it.
- */
 LIBSBML_EXTERN
 Layout_t *
 Layout_create (void)
@@ -2566,9 +2579,6 @@ Layout_create (void)
 }
 
 
-/**
- * Creates a new Layout with the given @p id and returns a pointer to it.
- */
 LIBSBML_EXTERN
 Layout_t *
 Layout_createWith (const char *sid)
@@ -2582,9 +2592,6 @@ Layout_createWith (const char *sid)
 }
 
 
-/**
- * Creates a Layout object from a template.
- */
 LIBSBML_EXTERN
     Layout_t *
 Layout_createFrom (const Layout_t *temp)
@@ -2593,27 +2600,19 @@ Layout_createFrom (const Layout_t *temp)
 }
 
 
-/**
- * Creates a new Layout with the given width, height and depth and returns
- * a pointer to it.  The depth value defaults to 0.0.
- */
 LIBSBML_EXTERN
 Layout_t *
 Layout_createWithSize (const char *id,
                        double width, double height, double depth)
 {
-    LayoutPkgNamespaces layoutns;
-    Dimensions* d=new Dimensions(&layoutns, width,height,depth);
-    Layout_t* l=new (std::nothrow) Layout(&layoutns, id ? id : "", d);
-    delete d;
-    return l;
+  LayoutPkgNamespaces layoutns;
+  Dimensions* d=new Dimensions(&layoutns, width,height,depth);
+  Layout_t* l=new (std::nothrow) Layout(&layoutns, id ? id : "", d);
+  delete d;
+  return l;
 }
 
 
-/**
- * Creates a new Layout with the given Dimensions and returns a pointer to
- * it.
- */
 LIBSBML_EXTERN
 Layout_t *
 Layout_createWithDimensions (const char *id, const Dimensions_t *dimensions)
@@ -2623,9 +2622,6 @@ Layout_createWithDimensions (const char *id, const Dimensions_t *dimensions)
 }
 
 
-/** 
- * Frees the memory for the given layout.
- */
 LIBSBML_EXTERN
 void
 Layout_free (Layout_t *l)
@@ -2634,516 +2630,394 @@ Layout_free (Layout_t *l)
 }
 
 
-
-/**
- * Sets the dimensions of the layout.
- */
 LIBSBML_EXTERN
 void
 Layout_setDimensions (Layout_t *l, const Dimensions_t *dimensions)
 {
-    static_cast<Layout*>(l)->setDimensions( dimensions );
+  if (l == NULL) return;
+  static_cast<Layout*>(l)->setDimensions( dimensions );
 }
 
 
-/**
- * Adds a new compartment glyph to the list of compartment glyphs.
- */
 LIBSBML_EXTERN
 void
 Layout_addCompartmentGlyph (Layout_t *l, CompartmentGlyph_t *cg)
 {
+  if (l == NULL) return;
   l->addCompartmentGlyph(cg);
 }
 
 
-/**
- * Adds a new species glyph to the list of species glyphs.
- */
 LIBSBML_EXTERN
 void
 Layout_addSpeciesGlyph (Layout_t *l, SpeciesGlyph_t *sg)
 {
+  if (l == NULL) return;
   l->addSpeciesGlyph(sg);
 }
 
 
-/**
- * Adds a new reaction glyph to the list of reaction glyphs.
- */
 LIBSBML_EXTERN
 void
 Layout_addReactionGlyph (Layout_t *l, ReactionGlyph_t *rg)
 {
+  if (l == NULL) return;
   l->addReactionGlyph(rg);
 }
 
 
-/**
- * Adds a new TextGlyph to the list of text glyphs.
- */
 LIBSBML_EXTERN
 void
 Layout_addTextGlyph (Layout_t *l, TextGlyph_t *tg)
 {
+  if (l == NULL) return;
   l->addTextGlyph(tg);
 }
 
 
-/**
- * Adds a new GraphicalObject to the list of additional graphical objects.
- */
 LIBSBML_EXTERN
 void
 Layout_addAdditionalGraphicalObject (Layout_t *l, GraphicalObject_t *go)
 {
+  if (l == NULL) return;
   l->addAdditionalGraphicalObject(go);
 }
 
 
-/**
- * Returns a pointer to the CompartmentGlyph with the given index.
- */
 LIBSBML_EXTERN
 CompartmentGlyph_t *
 Layout_getCompartmentGlyph (Layout_t *l, unsigned int index)
 {
+  if (l == NULL) return NULL;
   return l->getCompartmentGlyph(index);
 }
 
 
-/**
- * Returns a pointer to the SpeciesGlyph with the given index.
- */
 LIBSBML_EXTERN
 SpeciesGlyph_t *
 Layout_getSpeciesGlyph (Layout_t *l, unsigned int index)
 {
+  if (l == NULL) return NULL;
   return l->getSpeciesGlyph(index);
 }
 
 
-/**
- * Returns a pointer to the ReactionGlyph with the given index.
- */
 LIBSBML_EXTERN
 ReactionGlyph_t *
 Layout_getReactionGlyph (Layout_t *l, unsigned int index)
 {
+  if (l == NULL) return NULL;
   return l->getReactionGlyph(index);
 }
 
 
-/**
- * Returns a pointer to the AdditionalGraphicalObject with the given index.
- */
 LIBSBML_EXTERN
 TextGlyph_t *
 Layout_getTextGlyph (Layout_t *l, unsigned int index)
 {
+  if (l == NULL) return NULL;
   return l->getTextGlyph(index);
 }
 
 
 
-/**
- * Returns a pointer to the GraphicalObject with the given index.
- */
 LIBSBML_EXTERN
 GraphicalObject_t *
 Layout_getAdditionalGraphicalObject (Layout_t *l, unsigned int index)
 {
+  if (l == NULL) return NULL;
   return l->getAdditionalGraphicalObject(index);
 }
 
 
-/**
- * Returns a pointer to the list of CompartmentGlyphs.
- */
 LIBSBML_EXTERN
 ListOf_t *
 Layout_getListOfCompartmentGlyphs (Layout_t *l)
 {
+  if (l == NULL) return NULL;
   return l->getListOfCompartmentGlyphs();
 }
 
 
-/**
- * Returns a pointer to the list of SpeciesGlyphs.
- */
 LIBSBML_EXTERN
 ListOf_t *
 Layout_getListOfSpeciesGlyphs (Layout_t *l)
 {
+  if (l == NULL) return NULL;
   return l->getListOfSpeciesGlyphs();
 }
 
 
-/**
- * Returns a pointer to the list of ReactionGlyphs.
- */
 LIBSBML_EXTERN
 ListOf_t *
 Layout_getListOfReactionGlyphs (Layout_t *l)
 {
+  if (l == NULL) return NULL;
   return l->getListOfReactionGlyphs();
 }
 
 
-/**
- * Returns a pointer to the list of TextGlyphs.
- */
 LIBSBML_EXTERN
 ListOf_t *
 Layout_getListOfTextGlyphs (Layout_t *l)
 {
+  if (l == NULL) return NULL;
   return l->getListOfTextGlyphs();
 }
 
 
-/**
- * Returns a pointer to the list of additional GraphicalObjects.
- */
 LIBSBML_EXTERN
 ListOf_t *
 Layout_getListOfAdditionalGraphicalObjects (Layout_t *l)
 {
+  if (l == NULL) return NULL;
   return l->getListOfAdditionalGraphicalObjects();
 }
 
 
-
-/**
- * @return the dimensions of the layout
- */
 LIBSBML_EXTERN
 Dimensions_t*
 Layout_getDimensions(Layout_t *l)
 {
+  if (l == NULL) return NULL;
   return l->getDimensions();
 }
 
 
-/**
- * Returns the number of CompartmentGlyphs.
- */
 LIBSBML_EXTERN
 unsigned int
 Layout_getNumCompartmentGlyphs (const Layout_t *l)
 {
+  if (l == NULL) return 0;
   return l->getNumCompartmentGlyphs();
 }
 
 
-/**
- * Returns the number of SpeciesGlyphs.
- */
 LIBSBML_EXTERN
 unsigned int
 Layout_getNumSpeciesGlyphs (const Layout_t *l)
 {
+  if (l == NULL) return 0;
   return l->getNumSpeciesGlyphs();
 }
 
 
-/**
- * Returns the number of ReactionGlyphs.
- */
 LIBSBML_EXTERN
 unsigned int
 Layout_getNumReactionGlyphs (const Layout_t *l)
 {
+  if (l == NULL) return 0;
   return l->getNumReactionGlyphs();
 }
 
 
-/**
- * Returns the number of TextGlyphs.
- */
 LIBSBML_EXTERN
 unsigned int
 Layout_getNumTextGlyphs (const Layout_t *l)
 {
+  if (l == NULL) return 0;
   return l->getNumTextGlyphs();
 }
 
 
-/**
- * Returns the number of additional GraphicalObject.
- */
 LIBSBML_EXTERN
 unsigned int
 Layout_getNumAdditionalGraphicalObjects (const Layout_t *l)
 {
+  if (l == NULL) return 0;
   return l->getNumAdditionalGraphicalObjects();
 }
 
 
-/**
- * Does nothing since no defaults are defined for Layout.
- */ 
 LIBSBML_EXTERN
 void
 Layout_initDefaults (Layout_t *l)
 {
+  if (l == NULL) return;
   l->initDefaults();
 }
 
 
 
-/**
- * Creates a ComparmentGlyph_t object, adds it to the end of the
- * compartment glyphs objects list and returns a pointer to the newly
- * created object.
- */
 LIBSBML_EXTERN
 CompartmentGlyph_t *
 Layout_createCompartmentGlyph (Layout_t *l)
 {
+  if (l == NULL) return NULL;
   return l->createCompartmentGlyph();
 }
 
 
-/**
- * Creates a SpeciesGlyph object, adds it to the end of the species glyphs
- * objects list and returns a pointer to the newly created object.
- */
 LIBSBML_EXTERN
 SpeciesGlyph_t *
 Layout_createSpeciesGlyph (Layout_t *l)
 {
+  if (l == NULL) return NULL;
   return l->createSpeciesGlyph();
 }
 
 
-/**
- * Creates a ReactionGlyph_t object, adds it to the end of the reaction
- * glyphs objects list and returns a pointer to the newly created object.
- */
 LIBSBML_EXTERN
 ReactionGlyph_t *
 Layout_createReactionGlyph (Layout_t *l)
 {
+  if (l == NULL) return NULL;
   return l->createReactionGlyph();
 }
 
-/**
- * Creates a GeneralGlyph_t object, adds it to the end of the additional
- * objects list and returns a pointer to the newly created object.
- */
+
 LIBSBML_EXTERN
 GeneralGlyph_t *
 Layout_createGeneralGlyph (Layout_t *l)
 {
+  if (l == NULL) return NULL;
   return l->createGeneralGlyph();
 }
 
 
-
-/**
- * Creates a TextGlyph_t object, adds it to the end of the text glyphs
- * objects list and returns a pointer to the newly created object.
- */
 LIBSBML_EXTERN
 TextGlyph_t *
 Layout_createTextGlyph (Layout_t *l)
 {
+  if (l == NULL) return NULL;
   return l->createTextGlyph();
 }
 
 
-/**
- * Creates a GraphicalObject object, adds it to the end of the additional
- * graphical objects list and returns a pointer to the newly created
- * object.
- */
 LIBSBML_EXTERN
 GraphicalObject_t *
 Layout_createAdditionalGraphicalObject (Layout_t *l)
 {
+  if (l == NULL) return NULL;
   return l->createAdditionalGraphicalObject();
 }
 
-/**
- * Remove the compartment glyph with the given index.
- * A pointer to the removed object is returned. If no object was removed, NULL
- * is returned.
- */
 LIBSBML_EXTERN
 CompartmentGlyph_t*
 Layout_removeCompartmentGlyph(Layout_t* l, unsigned int index)
 {
-    return l->removeCompartmentGlyph(index);
+  if (l == NULL) return NULL;
+  return l->removeCompartmentGlyph(index);
 }
 
-/**
- * Remove the species glyph with the given index.
- * A pointer to the removed object is returned. If no object was removed, NULL
- * is returned.
- */
 LIBSBML_EXTERN
 SpeciesGlyph_t*
 Layout_removeSpeciesGlyph(Layout_t* l, unsigned int index)
 {
-    return l->removeSpeciesGlyph(index);
+  if (l == NULL) return NULL;
+  return l->removeSpeciesGlyph(index);
 }
 
-/**
- * Remove the reaction glyph with the given index.
- * A pointer to the removed object is returned. If no object was removed, NULL
- * is returned.
- */
 LIBSBML_EXTERN
 ReactionGlyph_t*
 Layout_removeReactionGlyph(Layout_t* l, unsigned int index)
 {
-    return l->removeReactionGlyph(index);
+  if (l == NULL) return NULL;
+  return l->removeReactionGlyph(index);
 }
 
-/**
- * Remove the text glyph with the given index.
- * A pointer to the removed object is returned. If no object was removed, NULL
- * is returned.
- */
 LIBSBML_EXTERN
 TextGlyph_t*
 Layout_removeTextGlyph(Layout_t* l, unsigned int index)
 {
-    return l->removeTextGlyph(index);
+  if (l == NULL) return NULL;
+  return l->removeTextGlyph(index);
 }
 
-/**
- * Remove the graphical object with the given index.
- * A pointer to the removed object is returned. If no object was removed, NULL
- * is returned.
- */
 LIBSBML_EXTERN
 GraphicalObject_t*
 Layout_removeAdditionalGraphicalObject(Layout_t* l, unsigned int index)
 {
-    return l->removeAdditionalGraphicalObject(index);
+  if (l == NULL) return NULL;
+  return l->removeAdditionalGraphicalObject(index);
 }
 
-/**
- * Remove the compartment glyph with the given @p id.
- * A pointer to the removed object is returned. If no object was removed, NULL
- * is returned.
- */
 LIBSBML_EXTERN
 CompartmentGlyph_t*
 Layout_removeCompartmentGlyphWithId(Layout_t* l, const char* id)
 {
-    return l->removeCompartmentGlyph(id);
+  if (l == NULL) return NULL;
+  return l->removeCompartmentGlyph(id);
 }
 
-/**
- * Remove the species glyph with the given @p id.
- * A pointer to the removed object is returned. If no object was removed, NULL
- * is returned.
- */
 LIBSBML_EXTERN
 SpeciesGlyph_t*
 Layout_removeSpeciesGlyphWithId(Layout_t* l, const char* id)
 {
-    return l->removeSpeciesGlyph(id);
+  if (l == NULL) return NULL;
+  return l->removeSpeciesGlyph(id);
 }
 
-/**
- * Remove the reaction glyph with the given @p id.
- * A pointer to the removed object is returned. If no object was removed, NULL
- * is returned.
- */
 LIBSBML_EXTERN
 ReactionGlyph_t*
 Layout_removeReactionGlyphWithId(Layout_t* l, const char* id)
 {
-    return l->removeReactionGlyph(id);
+  if (l == NULL) return NULL;
+  return l->removeReactionGlyph(id);
 }
 
-/**
- * Remove the text glyph with the given @p id.
- * A pointer to the removed object is returned. If no object was removed, NULL
- * is returned.
- */
 LIBSBML_EXTERN
 TextGlyph_t*
 Layout_removeTextGlyphWithId(Layout_t* l, const char* id)
 {
-    return l->removeTextGlyph(id);
+  if (l == NULL) return NULL;
+  return l->removeTextGlyph(id);
 }
 
-/**
- * Remove the species reference glyph with the given @p id.
- * A pointer to the removed object is returned. If no object was removed, NULL
- * is returned.
- */
 LIBSBML_EXTERN
 SpeciesReferenceGlyph_t*
 Layout_removeSpeciesReferenceGlyphWithId(Layout_t* l, const char* id)
 {
-    return l->removeSpeciesReferenceGlyph(id);
+  if (l == NULL) return NULL;
+  return l->removeSpeciesReferenceGlyph(id);
 }
 
-/**
- * Remove the graphical object with the given @p id.
- * A pointer to the removed object is returned. If no object was removed, NULL
- * is returned.
- */
 LIBSBML_EXTERN
 GraphicalObject_t*
 Layout_removeAdditionalGraphicalObjectWithId(Layout_t* l, const char* id)
 {
-    return l->removeAdditionalGraphicalObject(id);
+  if (l == NULL) return NULL;
+  return l->removeAdditionalGraphicalObject(id);
 }
 
-/**
- * @return a (deep) copy of this Layout.
- */
 LIBSBML_EXTERN
 Layout_t *
 Layout_clone (const Layout_t *m)
 {
+  if (m == NULL) return NULL;
   return static_cast<Layout*>( m->clone() );
 }
 
 
-/**
- * Returns non-zero if the id is set
- */
 LIBSBML_EXTERN
 int
 Layout_isSetId (const Layout_t *l)
 {
+  if (l == NULL) return (int)false;
   return static_cast <int> (l->isSetId());
 }
 
-/**
- * Returns the id
- */
 LIBSBML_EXTERN
 const char *
 Layout_getId (const Layout_t *l)
 {
+  if (l == NULL) return NULL;
   return l->isSetId() ? l->getId().c_str() : NULL;
 }
 
-/**
- * Sets the id
- */
 LIBSBML_EXTERN
 int
 Layout_setId (Layout_t *l, const char *sid)
 {
+  if (l == NULL) return (int)false;
   return (sid == NULL) ? l->setId("") : l->setId(sid);
 }
 
-/**
- * Unsets the id
- */
 LIBSBML_EXTERN
 void
 Layout_unsetId (Layout_t *l)
 {
+  if (l == NULL) return;
   l->unsetId();
 }
 
