@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ * 
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2004-2008 by European Media Laboratories Research gGmbH,
  *     Heidelberg, Germany
@@ -698,11 +703,8 @@ LineSegment::enablePackageInternal(const std::string& pkgURI,
 
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
+/** @cond doxygenIgnored */
 
-/**
- * Creates a LineSegment and returns the pointer.
- */
 LIBSBML_EXTERN
 LineSegment_t *
 LineSegment_create (void)
@@ -711,9 +713,6 @@ LineSegment_create (void)
 }
 
 
-/**
- * Creates a LineSegment from a template.
- */
 LIBSBML_EXTERN
 LineSegment_t *
 LineSegment_createFrom (const LineSegment_t *temp)
@@ -722,9 +721,6 @@ LineSegment_createFrom (const LineSegment_t *temp)
 }
 
 
-/**
- * Creates a LineSegment with the given points and returns the pointer.
- */
 LIBSBML_EXTERN
 LineSegment_t *
 LineSegment_createWithPoints (const Point_t *start, const Point_t *end)
@@ -734,9 +730,6 @@ LineSegment_createWithPoints (const Point_t *start, const Point_t *end)
 }
 
 
-/**
- * Creates a LineSegment with the given coordinates and returns the pointer.
- */
 LIBSBML_EXTERN
 LineSegment_t *
 LineSegment_createWithCoordinates (double x1, double y1, double z1,
@@ -747,9 +740,6 @@ LineSegment_createWithCoordinates (double x1, double y1, double z1,
 }
 
 
-/**
- * Frees the memory for the line segment.
- */
 LIBSBML_EXTERN
 void
 LineSegment_free (LineSegment_t *ls)
@@ -758,67 +748,56 @@ LineSegment_free (LineSegment_t *ls)
 }
 
 
-/**
- * Initializes the start point with a copy of the given Point object.
- */
 LIBSBML_EXTERN
 void
 LineSegment_setStart (LineSegment_t *ls, const Point_t *start)
 {
+  if (ls == NULL) return;
   ls->setStart(start);
 }
 
 
-/**
- * Initializes the end point with a copy of the given Point object.
- */
 LIBSBML_EXTERN
 void
 LineSegment_setEnd (LineSegment_t *ls, const Point_t *end)
 {
+  if (ls == NULL) return;
   ls->setEnd(end);
 }
 
 
-/**
- * Returns the start point of the line.
- */ 
 LIBSBML_EXTERN
 Point_t *
 LineSegment_getStart (LineSegment_t *ls)
 {
+  if (ls == NULL) return NULL;
   return ls->getStart();
 }
 
 
-/**
- * Returns the end point of the line.
- */ 
 LIBSBML_EXTERN
 Point_t *
 LineSegment_getEnd (LineSegment_t *ls)
 {
+  if (ls == NULL) return NULL;
   return ls->getEnd();
 }
 
 
-/**
- * Does nothing since no defaults are defined for LineSegment.
- */ 
 LIBSBML_EXTERN
 void
 LineSegment_initDefaults (LineSegment_t *ls)
 {
+  if (ls == NULL) return;
   ls->initDefaults();
 }
 
-/**
- * @return a (deep) copy of this LineSegment.
- */
+
 LIBSBML_EXTERN
 LineSegment_t *
 LineSegment_clone (const LineSegment_t *m)
 {
+  if (m == NULL) return NULL;
   return static_cast<LineSegment*>( m->clone() );
 }
 
