@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ * 
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2004-2008 by European Media Laboratories Research gGmbH,
  *     Heidelberg, Germany
@@ -40,6 +45,8 @@
 LIBSBML_CPP_NAMESPACE_BEGIN
 #ifdef __cplusplus
 
+using namespace std;
+
 /*
  * Creates a new point with x,y and z set  to 0.0.
  */ 
@@ -687,11 +694,8 @@ bool Point::accept (SBMLVisitor& v) const
 
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
+/** @cond doxygenIgnored */
 
-/**
- * Creates a new point with the coordinates (0.0,0.0,0.0).
- */ 
 LIBSBML_EXTERN
 Point_t *
 Point_create (void)
@@ -700,9 +704,6 @@ Point_create (void)
 }
 
 
-/**
- * Creates a new Point with the given coordinates.
- */ 
 LIBSBML_EXTERN
 Point_t *
 Point_createWithCoordinates (double x, double y, double z)
@@ -712,9 +713,6 @@ Point_createWithCoordinates (double x, double y, double z)
 }
 
 
-/**
- * Frees all memory for the Point.
- */ 
 LIBSBML_EXTERN
 void
 Point_free (Point_t *p)
@@ -723,166 +721,136 @@ Point_free (Point_t *p)
 }
 
 
-/**
- * Sets the Z offset to 0.0
- */ 
 LIBSBML_EXTERN
 void
 Point_initDefaults (Point_t *p)
 {
+  if (p == NULL) return;
   p->initDefaults();
 }
 
 
-/**
- * Sets the coordinates to the given values.
- */ 
 LIBSBML_EXTERN
 void
 Point_setOffsets (Point_t *p, double x, double y, double z)
 {
+  if (p == NULL) return;
   p->setOffsets(x, y, z);
 }
 
 
-/**
- * Sets the x offset.
- */ 
 LIBSBML_EXTERN
 void
 Point_setXOffset (Point_t *p, double x)
 {
+  if (p == NULL) return;
   p->setX(x);
 }
 
 
-/**
- * Sets the y offset.
- */ 
 LIBSBML_EXTERN
 void
 Point_setYOffset (Point_t *p, double y)
 {
+  if (p == NULL) return;
   p->setY(y);
 }
 
 
-/**
- * Sets the z offset.
- */ 
 LIBSBML_EXTERN
 void
 Point_setZOffset (Point_t *p, double z)
 {
+  if (p == NULL) return;
   p->setZ(z);
 }
 
 
-/**
- * Gets the x offset.
- */ 
 LIBSBML_EXTERN
 double
 Point_getXOffset (const Point_t *p)
 {
+  if (p == NULL) return numeric_limits<double>::quiet_NaN();
   return p->x();
 }
 
 
-/**
- * Gets the y offset.
- */ 
 LIBSBML_EXTERN
 double
 Point_getYOffset (const Point_t *p)
 {
+  if (p == NULL) return numeric_limits<double>::quiet_NaN();
   return p->y();
 }
 
 
-/**
- * Gets the z offset.
- */ 
 LIBSBML_EXTERN
 double
 Point_getZOffset (const Point_t *p)
 {
+  if (p == NULL) return numeric_limits<double>::quiet_NaN();
   return p->z();
 }
 
 
-/**
- * Sets the x offset.
- */ 
 LIBSBML_EXTERN
 void
 Point_setX (Point_t *p, double x)
 {
+  if (p == NULL) return;
   p->setX(x);
 }
 
 
-/**
- * Sets the y offset.
- */ 
 LIBSBML_EXTERN
 void
 Point_setY (Point_t *p, double y)
 {
+  if (p == NULL) return;
   p->setY(y);
 }
 
 
-/**
- * Sets the z offset.
- */ 
 LIBSBML_EXTERN
 void
 Point_setZ (Point_t *p, double z)
 {
+  if (p == NULL) return;
   p->setZ(z);
 }
 
 
-/**
- * Gets the x offset.
- */ 
 LIBSBML_EXTERN
 double
 Point_x (const Point_t *p)
 {
+  if (p == NULL) return numeric_limits<double>::quiet_NaN();
   return p->x();
 }
 
 
-/**
- * Gets the y offset.
- */ 
 LIBSBML_EXTERN
 double
 Point_y (const Point_t *p)
 {
+  if (p == NULL) return numeric_limits<double>::quiet_NaN();
   return p->y();
 }
 
 
-/**
- * Gets the z offset.
- */ 
 LIBSBML_EXTERN
 double
 Point_z (const Point_t *p)
 {
+  if (p == NULL) return numeric_limits<double>::quiet_NaN();
   return p->z();
 }
 
-/**
- * @return a (deep) copy of this Point.
- */
 LIBSBML_EXTERN
 Point_t *
 Point_clone (const Point_t *m)
 {
+  if (m == NULL) return NULL;
   return static_cast<Point*>( m->clone() );
 }
 
