@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ * 
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2004-2008 by European Media Laboratories Research gGmbH,
  *     Heidelberg, Germany
@@ -98,7 +103,7 @@ TextGlyph::TextGlyph (LayoutPkgNamespaces* layoutns)
 
 
 /*
- * Creates a new TextGlpyh. The id is given as the first argument.
+ * Creates a new TextGlyph. The id is given as the first argument.
  */ 
 TextGlyph::TextGlyph (LayoutPkgNamespaces* layoutns, const std::string& id)
  : GraphicalObject(layoutns, id)
@@ -121,7 +126,7 @@ TextGlyph::TextGlyph (LayoutPkgNamespaces* layoutns, const std::string& id)
 }
 
 /*
- * Creates a new TextGlpyh. The id is given as the first argument, the text
+ * Creates a new TextGlyph. The id is given as the first argument, the text
  * to be displayed as the second.  All other attirbutes are set to the
  * empty string.
  */ 
@@ -551,11 +556,8 @@ XMLNode TextGlyph::toXML() const
 
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
+/** @cond doxygenIgnored */
 
-/**
- * Creates a new TextGlyph and returns the pointer to it.
- */
 LIBSBML_EXTERN
 TextGlyph_t *
 TextGlyph_create (void)
@@ -564,9 +566,6 @@ TextGlyph_create (void)
 }
 
 
-/**
- * Creates a new TextGlyph from a template.
- */
 LIBSBML_EXTERN
 TextGlyph_t *
 TextGlyph_createFrom (const TextGlyph_t *temp)
@@ -575,9 +574,6 @@ TextGlyph_createFrom (const TextGlyph_t *temp)
 }
 
 
-/**
- * Creates a new TextGlyph with the given @p id
- */
 LIBSBML_EXTERN
 TextGlyph_t *
 TextGlyph_createWith (const char *sid)
@@ -587,9 +583,6 @@ TextGlyph_createWith (const char *sid)
 }
 
 
-/**
- * Creates a new TextGlyph referencing the give text.
- */
 LIBSBML_EXTERN
 TextGlyph_t *
 TextGlyph_createWithText (const char *id, const char *text)
@@ -599,9 +592,6 @@ TextGlyph_createWithText (const char *id, const char *text)
 }
 
 
-/**
- * Frees the memory taken by the given text glyph.
- */
 LIBSBML_EXTERN
 void
 TextGlyph_free (TextGlyph_t *tg)
@@ -610,129 +600,101 @@ TextGlyph_free (TextGlyph_t *tg)
 }
 
 
-/**
- * Sets the text for the text glyph.
- */
 LIBSBML_EXTERN
 void
 TextGlyph_setText (TextGlyph_t *tg, const char *text)
 {
-    tg->setText( text ? text : "" );
+  if (tg == NULL) return;
+  tg->setText( text ? text : "" );
 }
 
 
-/**
- * Sets the id of the origin of the text for the text glyph.  This can be
- * the id of any valid sbml model object. The name of the object is then
- * taken as the text for the TextGlyph.
- */
 LIBSBML_EXTERN
 void
 TextGlyph_setOriginOfTextId (TextGlyph_t *tg, const char *sid)
 {
-    tg->setOriginOfTextId( sid ? sid : "" );
+  if (tg == NULL) return;
+  tg->setOriginOfTextId( sid ? sid : "" );
 }
 
 
-/**
- * Sets the assoziated GraphicalObject id for the text glyph.  A TextGlyph
- * which is assoziated with a GraphicalObject can be considered as a label
- * to that object and they might for example be moved together in an
- * editor.
- */
 LIBSBML_EXTERN
 void
 TextGlyph_setGraphicalObjectId (TextGlyph_t *tg, const char *sid)
 {
-    tg->setGraphicalObjectId( sid ? sid : "" );
+  if (tg == NULL) return;
+  tg->setGraphicalObjectId( sid ? sid : "" );
 }
 
 
-/**
- * Returns the text associated with this text glyph.
- */
 LIBSBML_EXTERN
 const char *
 TextGlyph_getText (const TextGlyph_t *tg)
 {
-    return tg->isSetText() ? tg->getText().c_str() : NULL;
+  if (tg == NULL) return NULL;
+  return tg->isSetText() ? tg->getText().c_str() : NULL;
 }
 
 
-/**
- * Returns the id of the origin of the text associated with this text
- * glyph.
- */
 LIBSBML_EXTERN
 const char *
 TextGlyph_getGraphicalObjectId (const TextGlyph_t *tg)
 {
-    return tg->isSetGraphicalObjectId() ? tg->getGraphicalObjectId().c_str() : NULL;
+  if (tg == NULL) return NULL;
+  return tg->isSetGraphicalObjectId() ? tg->getGraphicalObjectId().c_str() : NULL;
 }
 
 
-/**
- * Returns the id of the graphical object associated with this text glyph.
- */
 LIBSBML_EXTERN
 const char *
 TextGlyph_getOriginOfTextId (const TextGlyph_t *tg)
 {
-    return tg->isSetOriginOfTextId() ? tg->getOriginOfTextId().c_str() : NULL;
+  if (tg == NULL) return NULL;
+  return tg->isSetOriginOfTextId() ? tg->getOriginOfTextId().c_str() : NULL;
 }
 
 
-/**
- * Returns true is the text attribute is not the empty string.
- */
 LIBSBML_EXTERN
 int
 TextGlyph_isSetText (const TextGlyph_t *tg)
 {
+  if (tg == NULL) return (int)false;
   return static_cast<int>( tg->isSetText() );
 }
 
 
-/**
- * Returns true is the originOfText attribute is not the empty string.
- */
 LIBSBML_EXTERN
 int
 TextGlyph_isSetOriginOfTextId (const TextGlyph_t *tg)
 {
+  if (tg == NULL) return (int)false;
   return static_cast<int>( tg->isSetOriginOfTextId() );
 }
 
 
-/**
- * Returns true is the id of the associated graphical object is not the
- * empty string.
- */
 LIBSBML_EXTERN
 int
 TextGlyph_isSetGraphicalObjectId (const TextGlyph_t *tg)
 {
+  if (tg == NULL) return (int)false;
   return static_cast<int>( tg->isSetGraphicalObjectId() );
 }
 
 
-/**
- * Calls initDefaults from GraphicalObject.
- */ 
 LIBSBML_EXTERN
 void
 TextGlyph_initDefaults (TextGlyph_t *tg)
 {
+  if (tg == NULL) return;
   tg->initDefaults();
 }
 
-/**
- * @return a (deep) copy of this TextGlyph.
- */
+
 LIBSBML_EXTERN
 TextGlyph_t *
 TextGlyph_clone (const TextGlyph_t *m)
 {
+  if (m == NULL) return NULL;
   return static_cast<TextGlyph*>( m->clone() );
 }
 
