@@ -1,4 +1,6 @@
 /**
+ * @cond doxygenLibsbmlInternal
+ *
  * @file    XMLOutputStream.cpp
  * @brief   XMLOutputStream
  * @author  Ben Bornstein
@@ -7,9 +9,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ *
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -37,13 +44,10 @@
 #include <sbml/util/util.h>
 #include <sbml/common/common.h>
 #include <sbml/common/libsbml-version.h>
-
-/** @cond doxygenIgnored */
+#include <sbml/SBMLNamespaces.h>
 
 using namespace std;
 
-/** @endcond */
-
 LIBSBML_CPP_NAMESPACE_BEGIN
 #ifdef __cplusplus
 
@@ -169,7 +173,6 @@ bool hasPredefinedEntity(const std::string &chars, size_t index)
 }   
 
 
-/** @cond doxygenLibsbmlInternal */
 /**
  * Copy Constructor, made private so as to notify users, that copying an input stream is not supported. 
  */
@@ -185,9 +188,8 @@ XMLOutputStream::XMLOutputStream (const XMLOutputStream& other)
   , mStringStream(other.mStringStream)
 {
 }
-/** @endcond */
 
-/** @cond doxygenLibsbmlInternal */
+
 /**
  * Assignment operator, made private so as to notify users, that copying an input stream is not supported. 
  */
@@ -195,7 +197,7 @@ XMLOutputStream& XMLOutputStream::operator=(const XMLOutputStream& other)
 {
   return *this;
 }
-/** @endcond */
+
 
 /*
  * Creates a new XMLOutputStream that wraps stream.
@@ -213,6 +215,7 @@ XMLOutputStream::XMLOutputStream (  std::ostream&       stream
  , mInText  ( false    )
  , mSkipNextIndent ( false    )
  , mNextAmpersandIsRef( false )
+ , mSBMLns (NULL)
 {
   if (&stream == NULL)
     throw XMLConstructorException();
@@ -759,7 +762,6 @@ XMLOutputStream::upIndent ()
 }
 
 
-/** @cond doxygenLibsbmlInternal */
 /*
  * Outputs indentation whitespace.
  */
@@ -772,10 +774,8 @@ XMLOutputStream::writeIndent (bool isEnd)
     for (unsigned int n = 0; n < mIndent; ++n) mStream << ' ' << ' ';
   }
 }
-/** @endcond */
 
 
-/** @cond doxygenLibsbmlInternal */
 /*
  * Outputs the given characters to the underlying stream.
  */
@@ -793,10 +793,8 @@ XMLOutputStream::writeChars (const std::string& chars)
     *this << c;
   }
 }
-/** @endcond */
 
 
-/** @cond doxygenLibsbmlInternal */
 /*
  * Outputs name.
  */
@@ -811,10 +809,8 @@ XMLOutputStream::writeName (const std::string& name, const std::string &prefix)
 
   writeChars(name);
 }
-/** @endcond */
 
 
-/** @cond doxygenLibsbmlInternal */
 /*
  * Outputs prefix:name.
  */
@@ -829,10 +825,8 @@ XMLOutputStream::writeName (const XMLTriple& triple)
 
   writeChars( triple.getName() );
 }
-/** @endcond */
 
 
-/** @cond doxygenLibsbmlInternal */
 /*
  * Outputs value in quotes.
  */
@@ -854,10 +848,8 @@ XMLOutputStream::writeValue (const char* value)
   writeChars(value);
   mStream << '"';
 }
-/** @endcond */
 
 
-/** @cond doxygenLibsbmlInternal */
 /*
  * Outputs "true" or "false" in quotes.
  */
@@ -866,10 +858,8 @@ XMLOutputStream::writeValue (const bool& value)
 {
   mStream << '=' << '"' << (value ? "true" : "false") << '"';
 }
-/** @endcond */
 
 
-/** @cond doxygenLibsbmlInternal */
 /*
  * Outputs the double value in quotes, or "INF", "-INF", or "NaN".
  */
@@ -898,10 +888,8 @@ XMLOutputStream::writeValue (const double& value)
 
   mStream << '"';
 }
-/** @endcond */
 
 
-/** @cond doxygenLibsbmlInternal */
 /*
  * Outputs the long value in quotes.
  */
@@ -910,10 +898,8 @@ XMLOutputStream::writeValue (const long& value)
 {
   mStream << '=' << '"' << value << '"';
 }
-/** @endcond */
 
 
-/** @cond doxygenLibsbmlInternal */
 /*
  * Outputs the int value in quotes.
  */
@@ -922,10 +908,8 @@ XMLOutputStream::writeValue (const int& value)
 {
   mStream << '=' << '"' << value << '"';
 }
-/** @endcond */
 
 
-/** @cond doxygenLibsbmlInternal */
 /*
  * Outputs the int value in quotes.
  */
@@ -934,7 +918,6 @@ XMLOutputStream::writeValue (const unsigned int& value)
 {
   mStream << '=' << '"' << value << '"';
 }
-/** @endcond */
 
 
 /*
@@ -1070,7 +1053,31 @@ XMLOutputStream::operator<< (const char& c)
 }
 
 
-/** @cond doxygenLibsbmlInternal */
+SBMLNamespaces *
+XMLOutputStream::getSBMLNamespaces()
+{
+  return mSBMLns;
+}
+
+void
+XMLOutputStream::setSBMLNamespaces(SBMLNamespaces * sbmlns)
+{
+  if (mSBMLns  != NULL)
+    delete mSBMLns;
+  
+  if (sbmlns != NULL)
+    mSBMLns = sbmlns->clone();
+  else
+    mSBMLns = NULL;
+}
+
+XMLOutputStream::~XMLOutputStream()
+{
+  if (mSBMLns != NULL) 
+    delete mSBMLns;
+}
+
+
 
 XMLOutputStringStream::XMLOutputStringStream (  std::ostringstream& stream
                    , const std::string&  encoding
@@ -1085,6 +1092,7 @@ XMLOutputStringStream::XMLOutputStringStream (  std::ostringstream& stream
   setStringStream();
 }
 
+
 XMLOutputFileStream::XMLOutputFileStream (  std::ofstream& stream
                    , const std::string&  encoding
                    , bool                writeXMLDecl
@@ -1095,30 +1103,23 @@ XMLOutputFileStream::XMLOutputFileStream (  std::ofstream& stream
 {
 }
 
-/** @endcond */
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
-/**
- * Creates a new XMLOutputStream_t that wraps std output stream.
- **/
+
+
 LIBLAX_EXTERN
 XMLOutputStream_t *
-XMLOutputStream_createAsStdout (char * encoding, int writeXMLDecl)
+XMLOutputStream_createAsStdout (const char * encoding, int writeXMLDecl)
 {
   if (encoding == NULL) return NULL;
   return new(nothrow) XMLOutputStream(std::cout, encoding, writeXMLDecl);
 }
 
 
-/**
- * Creates a new XMLOutputStream_t that wraps std output stream
- * and adds program information as a comment.
- **/
 LIBLAX_EXTERN
 XMLOutputStream_t *
-XMLOutputStream_createAsStdoutWithProgramInfo (char * encoding,
-        int writeXMLDecl, char * programName, char * programVersion)
+XMLOutputStream_createAsStdoutWithProgramInfo (const char * encoding,
+        int writeXMLDecl, const char * programName, const char * programVersion)
 {
   if (encoding == NULL) return NULL;
   return new(nothrow) XMLOutputStream(std::cout, encoding, writeXMLDecl,
@@ -1126,12 +1127,9 @@ XMLOutputStream_createAsStdoutWithProgramInfo (char * encoding,
 }
 
 
-/**
- * Creates a new XMLOutputStream_t that wraps std string output stream.
- **/
 LIBLAX_EXTERN
 XMLOutputStream_t *
-XMLOutputStream_createAsString (char * encoding, int writeXMLDecl)
+XMLOutputStream_createAsString (const char * encoding, int writeXMLDecl)
 {
   if (encoding == NULL) return NULL;
 
@@ -1141,14 +1139,10 @@ XMLOutputStream_createAsString (char * encoding, int writeXMLDecl)
 }
 
 
-/**
- * Creates a new XMLOutputStream_t that wraps std string output stream
- * and adds program information as a comment.
-**/
 LIBLAX_EXTERN
 XMLOutputStream_t *
-XMLOutputStream_createAsStringWithProgramInfo (char * encoding,
-        int writeXMLDecl, char * programName, char * programVersion)
+XMLOutputStream_createAsStringWithProgramInfo (const char * encoding,
+        int writeXMLDecl, const char * programName, const char * programVersion)
 {
   if (encoding == NULL) return NULL;
 
@@ -1159,12 +1153,9 @@ XMLOutputStream_createAsStringWithProgramInfo (char * encoding,
 }
 
 
-/**
- * Creates a new XMLOutputStream_t that wraps std file output stream.
- **/
 LIBLAX_EXTERN
 XMLOutputStream_t *
-XMLOutputStream_createFile (char * filename, char * encoding, int writeXMLDecl)
+XMLOutputStream_createFile (const char * filename, const char * encoding, int writeXMLDecl)
 {
   if (filename == NULL || encoding == NULL) return NULL;
 
@@ -1173,14 +1164,10 @@ XMLOutputStream_createFile (char * filename, char * encoding, int writeXMLDecl)
 }
 
 
-/**
- * Creates a new XMLOutputStream_t that wraps std file output stream
- * and adds program information as a comment.
-**/
 LIBLAX_EXTERN
 XMLOutputStream_t *
-XMLOutputStream_createFileWithProgramInfo (char * filename, char * encoding, 
-        int writeXMLDecl, char * programName, char * programVersion)
+XMLOutputStream_createFileWithProgramInfo (const char * filename, const char * encoding, 
+        int writeXMLDecl, const char * programName, const char * programVersion)
 {
   if (filename == NULL || encoding == NULL) return NULL;
 
@@ -1190,9 +1177,6 @@ XMLOutputStream_createFileWithProgramInfo (char * filename, char * encoding,
 }
 
 
-/**
- * Deletes this XMLOutputStream_t. 
- **/
 LIBLAX_EXTERN
 void
 XMLOutputStream_free (XMLOutputStream_t *stream)
@@ -1202,10 +1186,6 @@ XMLOutputStream_free (XMLOutputStream_t *stream)
 }  
 
 
-/**
- * Writes the XML declaration:
- * <?xml version="1.0" encoding="..."?>
- */
 LIBLAX_EXTERN
 void 
 XMLOutputStream_writeXMLDecl (XMLOutputStream_t *stream)
@@ -1215,9 +1195,6 @@ XMLOutputStream_writeXMLDecl (XMLOutputStream_t *stream)
 }
 
 
-/**
- * Increases the indentation level for this XMLOutputStream.
- */
 LIBLAX_EXTERN
 void
 XMLOutputStream_upIndent(XMLOutputStream_t *stream)
@@ -1227,9 +1204,6 @@ XMLOutputStream_upIndent(XMLOutputStream_t *stream)
 }
 
 
-/**
- * Decreases the indentation level for this XMLOutputStream.
- */
 LIBLAX_EXTERN
 void
 XMLOutputStream_downIndent(XMLOutputStream_t *stream)
@@ -1239,9 +1213,6 @@ XMLOutputStream_downIndent(XMLOutputStream_t *stream)
 }
 
 
-/**
-  * Writes the given XML end element name to this XMLOutputStream.
-  */
 LIBLAX_EXTERN
 void 
 XMLOutputStream_endElement (XMLOutputStream_t *stream, const char* name)
@@ -1251,10 +1222,6 @@ XMLOutputStream_endElement (XMLOutputStream_t *stream, const char* name)
 }
 
 
-/**
- * Writes the given XML end element 'prefix:name' to this
- * XMLOutputStream.
- */
 LIBLAX_EXTERN
 void 
 XMLOutputStream_endElementTriple (XMLOutputStream_t *stream, 
@@ -1265,9 +1232,6 @@ XMLOutputStream_endElementTriple (XMLOutputStream_t *stream,
 }
 
 
-/**
- * Turns automatic indentation on or off for this XMLOutputStream.
- */
 LIBLAX_EXTERN
 void 
 XMLOutputStream_setAutoIndent (XMLOutputStream_t *stream, int indent)
@@ -1277,9 +1241,6 @@ XMLOutputStream_setAutoIndent (XMLOutputStream_t *stream, int indent)
 }
 
 
-/**
- * Writes the given XML start element name to this XMLOutputStream.
- */
 LIBLAX_EXTERN
 void 
 XMLOutputStream_startElement (XMLOutputStream_t *stream, const char* name)
@@ -1289,10 +1250,6 @@ XMLOutputStream_startElement (XMLOutputStream_t *stream, const char* name)
 }
 
 
-/**
- * Writes the given XML start element 'prefix:name' to this
- * XMLOutputStream.
- */
 LIBLAX_EXTERN
 void 
 XMLOutputStream_startElementTriple (XMLOutputStream_t *stream, 
@@ -1303,9 +1260,6 @@ XMLOutputStream_startElementTriple (XMLOutputStream_t *stream,
 }
 
 
-/**
- * Writes the given XML start and end element name to this XMLOutputStream.
- */
 LIBLAX_EXTERN
 void 
 XMLOutputStream_startEndElement (XMLOutputStream_t *stream, const char* name)
@@ -1315,10 +1269,6 @@ XMLOutputStream_startEndElement (XMLOutputStream_t *stream, const char* name)
 }
 
 
-/**
- * Writes the given XML start and end element 'prefix:name' to this
- * XMLOutputStream.
- */
 LIBLAX_EXTERN
 void 
 XMLOutputStream_startEndElementTriple (XMLOutputStream_t *stream, 
@@ -1329,9 +1279,6 @@ XMLOutputStream_startEndElementTriple (XMLOutputStream_t *stream,
 }
 
 
-/**
- * Writes the given attribute, name="value" to this XMLOutputStream.
- */
 LIBLAX_EXTERN
 void 
 XMLOutputStream_writeAttributeChars (XMLOutputStream_t *stream, 
@@ -1342,10 +1289,6 @@ XMLOutputStream_writeAttributeChars (XMLOutputStream_t *stream,
 }
 
 
-/**
- * Writes the given attribute, prefix:name="value" to this
- * XMLOutputStream.
- */
 LIBLAX_EXTERN
 void 
 XMLOutputStream_writeAttributeCharsTriple (XMLOutputStream_t *stream, 
@@ -1357,10 +1300,6 @@ XMLOutputStream_writeAttributeCharsTriple (XMLOutputStream_t *stream,
 }
 
 
-/**
- * Writes the given attribute, name="true" or name="false" to this
- * XMLOutputStream.
- */
 LIBLAX_EXTERN
 void 
 XMLOutputStream_writeAttributeBool (XMLOutputStream_t *stream, 
@@ -1372,10 +1311,6 @@ XMLOutputStream_writeAttributeBool (XMLOutputStream_t *stream,
 }
 
 
-/**
- * Writes the given attribute, prefix:name="true" or prefix:name="false"
- * to this XMLOutputStream.
- */
 LIBLAX_EXTERN
 void 
 XMLOutputStream_writeAttributeBoolTriple (XMLOutputStream_t *stream, 
@@ -1387,9 +1322,6 @@ XMLOutputStream_writeAttributeBoolTriple (XMLOutputStream_t *stream,
 }
 
 
-/**
- * Writes the given attribute, name="value" to this XMLOutputStream.
- */
 LIBLAX_EXTERN
 void 
 XMLOutputStream_writeAttributeDouble (XMLOutputStream_t *stream, 
@@ -1401,9 +1333,6 @@ XMLOutputStream_writeAttributeDouble (XMLOutputStream_t *stream,
 }
 
 
-/**
- * Writes the given attribute, prefix:name="value" to this XMLOutputStream.
- */
 LIBLAX_EXTERN
 void 
 XMLOutputStream_writeAttributeDoubleTriple (XMLOutputStream_t *stream, 
@@ -1415,9 +1344,6 @@ XMLOutputStream_writeAttributeDoubleTriple (XMLOutputStream_t *stream,
 }
 
 
-/**
- * Writes the given attribute, name="value" to this XMLOutputStream.
- */
 LIBLAX_EXTERN
 void 
 XMLOutputStream_writeAttributeLong (XMLOutputStream_t *stream, 
@@ -1429,9 +1355,6 @@ XMLOutputStream_writeAttributeLong (XMLOutputStream_t *stream,
 }
 
 
-/**
- * Writes the given attribute, prefix:name="value" to this XMLOutputStream.
- */
 LIBLAX_EXTERN
 void 
 XMLOutputStream_writeAttributeLongTriple (XMLOutputStream_t *stream, 
@@ -1443,9 +1366,6 @@ XMLOutputStream_writeAttributeLongTriple (XMLOutputStream_t *stream,
 }
 
 
-/**
- * Writes the given attribute, name="value" to this XMLOutputStream.
- */
 LIBLAX_EXTERN
 void 
 XMLOutputStream_writeAttributeInt (XMLOutputStream_t *stream, 
@@ -1457,9 +1377,6 @@ XMLOutputStream_writeAttributeInt (XMLOutputStream_t *stream,
 }
 
 
-/**
- * Writes the given attribute, prefix:name="value" to this XMLOutputStream.
- */
 LIBLAX_EXTERN
 void 
 XMLOutputStream_writeAttributeIntTriple (XMLOutputStream_t *stream, 
@@ -1471,9 +1388,6 @@ XMLOutputStream_writeAttributeIntTriple (XMLOutputStream_t *stream,
 }
 
 
-/**
- * Writes the given attribute, name="value" to this XMLOutputStream.
- */
 LIBLAX_EXTERN
 void 
 XMLOutputStream_writeAttributeUInt (XMLOutputStream_t *stream, 
@@ -1485,9 +1399,6 @@ XMLOutputStream_writeAttributeUInt (XMLOutputStream_t *stream,
 }
 
 
-/**
- * Writes the given attribute, prefix:name="value" to this XMLOutputStream.
- */
 LIBLAX_EXTERN
 void 
 XMLOutputStream_writeAttributeUIntTriple (XMLOutputStream_t *stream, 
@@ -1499,9 +1410,6 @@ XMLOutputStream_writeAttributeUIntTriple (XMLOutputStream_t *stream,
 }
 
 
-/**
- * Outputs the given characters to the underlying stream.
- */
 LIBLAX_EXTERN
 void
 XMLOutputStream_writeChars (XMLOutputStream_t *stream, const char* chars)
@@ -1511,9 +1419,6 @@ XMLOutputStream_writeChars (XMLOutputStream_t *stream, const char* chars)
 }
 
 
-/**
- * Outputs the given double to the underlying stream.
- */
 LIBLAX_EXTERN
 void
 XMLOutputStream_writeDouble (XMLOutputStream_t *stream, const double value)
@@ -1523,9 +1428,6 @@ XMLOutputStream_writeDouble (XMLOutputStream_t *stream, const double value)
 }
 
 
-/**
- * Outputs the given long to the underlying stream.
- */
 LIBLAX_EXTERN
 void
 XMLOutputStream_writeLong (XMLOutputStream_t *stream, const long value)
@@ -1535,9 +1437,6 @@ XMLOutputStream_writeLong (XMLOutputStream_t *stream, const long value)
 }
 
 
-/**
- * Returns the given string associated to the underlying string stream.
- */
 LIBLAX_EXTERN
 const char *
 XMLOutputStream_getString(XMLOutputStream_t* stream)
@@ -1555,8 +1454,6 @@ XMLOutputStream_getString(XMLOutputStream_t* stream)
 }
 
 
-/** @endcond */
-
 LIBSBML_CPP_NAMESPACE_END
 
-
+/** @endcond */
